* prog_1c.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns
*/

* Erstellung der im SUF nicht enthaltenen Rotationskennung (Proxy) mit zeitlich
* konsistenten Auswahlbezirksnummern.

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel"

log using prog_1c.log, text 

* erstellt mit prog_1b.do
use panel_v1b.dta, replace

/* 1. Schritt
Wertebereich der Auswahlbezirksnummer für Sätze mit gültigen Angaben in neu 
hinzugekommenen Rotationsvierteln, ohne Jahresüberhänge und Ausfallsätze. */

* Neues Rotationsviertel MZ 2012: 82 := ef45 = [-5] Entfällt (Keine Wiederholungsbefragung)
tabstat ef3 if t1==1 & file==1 & ef45==-5 & ef5b==0 & ef46>=1 & ef46<=2, s(count min p1 p5 p10 p50 p90 p95 p99 max)

* Neues Rotationsviertel MZ 2013: 83 := ef45 = [-5] Entfällt (Keine Wiederholungsbefragung)
tabstat ef3 if t2==1 & file==3 & ef45==-5 & ef5b==0 & ef46>=1 & ef46<=2, s(count min p1 p5 p10 p50 p90 p95 p99 max)

* Neues Rotationsviertel MZ 2014: 84 := ef45 = [-5] Entfällt (Keine Wiederholungsbefragung)
tabstat ef3 if t3==1 & file==5 & ef45==-5 & ef5b==0 & ef46>=1 & ef46<=2, s(count min p1 p5 p10 p50 p90 p95 p99 max)

* Neues Rotationsviertel MZ 2015: 91 := ef45 = [-5] Entfällt (Keine Wiederholungsbefragung)
tabstat ef3 if t4==1 & file==7 & ef45==-5 & ef5b==0 & ef46>=1 & ef46<=2, s(count min p1 p5 p10 p50 p90 p95 p99 max)

/* 2. Schritt
Wertebereiche der Auswahlbezirksnummer für Sätze mit gültigen Angaben in den
Erhebungen 2012, 2013 und 2014 letztmals befragter Rotationsgruppen 73, 74 
und 81, ohne Ad-hoc-Modul, Jahresüberhänge und Ausfallsätze */

* Rotationsviertel 73: 2009-2012 ?
tabstat ef3 if ptyp_psu==1 & ausftyp!=-1 & t1==1 & t2==0 & t3==0 & t4==0 & ef5b==0 & ef6==1 & ef46>=1 & ef46<=2 & ef45>=1 & ef45<=9, s(count min p1 p5 p10 p50 p90 p95 p99 max)

* Rotationsviertel 74: 2010-2013 ?
tabstat ef3 if ptyp_psu==2 & ausftyp!=-1 & (t1==1 | t2==1) & t3==0 & t4==0 & ef5b==0 & ef46>=1 & ef46<=2 & ef45>=1 & ef45<=9, s(count min p1 p5 p10 p50 p90 p95 p99 max)

* Rotationsviertel 81: 2011-2014 ?
tabstat ef3 if ptyp_psu==3 & ausftyp!=-1 & (t1==1 | t2==1 | t3==1) & t4==0 & ef5b==0 & ef46>=1 & ef46<=2 , s(count min p1 p5 p10 p50 p90 p95 p99 max)

/* 3. Schritt
Ergebnisse obiger Auswertungen zusammenstellen und nach plausiblen 
Wertebereichen der Rotationsgruppen für vorläufige Recodierung ordnen. */

recode ef3 (176134 / 188434 = 83) ///
           (275621 / 287787 = 82) ///
           (323028 / 335537 = 91) ///
           (344174 / 356524 = 84) ///
           (395006 / 407194 = 73) ///
           (480949 / 493199 = 81) ///
           (503242 / 515554 = 74) ///
           (* = 0), gen(rv_1)

* Kontrollen
* tab rv_1, m
* table ptyp_psu if rv_1==0, c(freq min ef3 med ef3 max ef3) row col miss

/* 4. Schritt
Für Haushalte des Jahresüberhangs und Ausfallsätze großzügigere Wertebereiche 
als in rv_1 ansetzen.
Mindestens 14.000 (entspricht etwa 
   Anzahl Auswahlbezirke (55700) / Anzahl Rotationsviertel (4) ).
Siehe StBA (2016): Qualitätsbericht Mikrozensus 2015 (Mikrozensus2015.pdf),
Seite 5. */

recode ef3 (170000 / 190000 = 83) ///
           (270000 / 290000 = 82) ///
           (320000 / 340000 = 91) ///
           (341000 / 360000 = 84) ///
           (390000 / 410000 = 73) ///
           (480000 / 500000 = 81) ///
           (501000 / 521000 = 74) ///
           (* = 0), gen(rot)

* Kontrollen
* tabstat ef3 , by(rot) s(count min p1 p5 p10 p25 p50 p75 p90 p95 p99 max) longstub

* tab ef5b_1 ef46_1 if file_1==1 & rot==0

* rot = 0 evtl. ROT 72 "2008-2011", da außerhalb des Wertebereichs ROT 73,
*         dennoch Zuordnung zu ROT 73, da Wertebereich am nächsten liegt.
replace rot = 73 if rot==0 
lab var rot "Rotationsgruppe <- ef3 (Proxy)"
* note rot : rot=73 enthält 65 Ausfallsätze mit min(ef3)=373587 und max(ef3)=384525, die evtl. zu rot=72 (2008-2011) gehören
lab def rot 73 "09-12" /// ?? evtl. rot 72 "2008-2011" ??
            74 "10-13" ///
            81 "11-14" ///
            82 "12-15" ///
            83 "13-16" /// -| 2015
            84 "14-17" /// -| 2015
            91 "15-18" /// -| 2015
	 , add modify 
lab val rot rot
numlabel rot, add mask("[#] ") force 

* Kontrollen
* tab ptyp rot_x, m
* tab ausftyp rot, m

* Arbeitsvariable löschen
drop rv_1

* ==============================================================================

save panel_v1c.dta, replace

log close

