* prog_1d.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns
*/

* Erstellung längsschnittkonsistenter Versionen des Geburtsjahres und des 
* Geschlechts

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using prog_1d.log, text

* erstellt mit prog_1c.do
use panel_v1c.dta, replace

* -----------------------------------------------------------------------------
* Response gültige Angaben | t
gen byte r1 = (ef46>=1 & ef46<=2 & t==1)
gen byte r2 = (ef46>=1 & ef46<=2 & t==2)
gen byte r3 = (ef46>=1 & ef46<=2 & t==3)
gen byte r4 = (ef46>=1 & ef46<=2 & t==4)
lab var r1 "Response (gültige Angaben) t1"
lab var r2 "Response (gültige Angaben) t2"
lab var r3 "Response (gültige Angaben) t3"
lab var r4 "Response (gültige Angaben) t4"
lab def r 0 "nein" 1 "ja"
numlabel r, add mask("[#] ") force 
format r1 r2 r3 r4 %1.0f

* Hilfsvariablen
egen double tx1 = total(r1==1), by(idpers)
egen double tx2 = total(r2==1), by(idpers)
egen double tx3 = total(r3==1), by(idpers)
egen double tx4 = total(r4==1), by(idpers)
gen double  tt  = (2*tx1*1000) + (3*tx2*100) + (4*tx3*10) + (5*tx4*1)
tab tt, m

* =====================================================

* sex <- Geschlecht längsschnittkonsistent

gen sex_1 = ef46 * (ef46>=1 & ef46<=2 & t==1)
gen sex_2 = ef46 * (ef46>=1 & ef46<=2 & t==2)
gen sex_3 = ef46 * (ef46>=1 & ef46<=2 & t==3)
gen sex_4 = ef46 * (ef46>=1 & ef46<=2 & t==4)
egen double tsex1 = total(sex_1), by(idpers)
egen double tsex2 = total(sex_2), by(idpers)
egen double tsex3 = total(sex_3), by(idpers)
egen double tsex4 = total(sex_4), by(idpers)

gen double  tsex  = (tsex1*1000) + (tsex2*100) + (tsex3*10) + (tsex4*1)
tab tsex if tt==2345

* -------------------------------------------------------
* sex <- 4x m oder 4x w
recode tsex (1111=1) (2222=2) (*=-1) if tt==2345, gen(sex)
* -------------------------------------------------------
* sex <- 3x m oder 3x w
replace sex = 1 if (tsex==1112 | tsex==1121 | tsex==1211 | tsex==2111) & tt==2345 & sex==-1
replace sex = 2 if (tsex==1222 | tsex==2122 | tsex==2212 | tsex==2221) & tt==2345 & sex==-1
* -------------------------------------------------------
* sex <- sex_1 falls 2x m oder 2x w
replace sex = 1 if tsex==1122 | tsex==1212 | tsex==1221 & tt==2345 & sex==-1
replace sex = 2 if tsex==2112 | tsex==2121 | tsex==2211 & tt==2345 & sex==-1
* -------------------------
* tt=2340 3x befragt
replace sex = 1 if (tsex==1110 | tsex==1120 | tsex==1210 | tsex==2110) & tt==2340
replace sex = 2 if (tsex==1220 | tsex==2120 | tsex==2210 | tsex==2220) & tt==2340
* --------------------------------------------
* tt=0345 3x befragt
replace sex = 1 if (tsex==111 | tsex==112 | tsex==121 | tsex==211) & tt== 345
replace sex = 2 if (tsex==122 | tsex==212 | tsex==221 | tsex==222) & tt== 345
* --------------------------
* tt=2305 3x befragt
replace sex = 1 if (tsex==1101 | tsex==1201 | tsex==2101) & tt== 2305
replace sex = 2 if (tsex==1202 | tsex==2102 | tsex==2202) & tt== 2305
* -----------------------------------------------
* tt=2045 3x befragt
replace sex = 1 if (tsex==1011 | tsex==2011)              & tt== 2045
replace sex = 2 if (tsex==1022 | tsex==2021 | tsex==2022) & tt== 2045
* --------------------------------------------
* tt=2300 2x befragt -> 1. Angabe
replace sex = 1 if (tsex==1100 | tsex==1200) & tt== 2300
replace sex = 2 if (tsex==2100 | tsex==2200) & tt== 2300
* -----------------------------
* tt=2040
replace sex = 1 if (tsex==1010 | tsex==1020) & tt== 2040
replace sex = 2 if (tsex==2010 | tsex==2020) & tt== 2040
* --------------------------------
* tt=2005 
replace sex = 1 if (tsex==1001 | tsex==1002) & tt== 2005
replace sex = 2 if (tsex==2002)              & tt== 2005
* -----------------------------------
* tt= 340
replace sex = 1 if (tsex==110 | tsex==120) & tt== 340
replace sex = 2 if (tsex==210 | tsex==220) & tt== 340
* -----------------------------
* tt= 305
replace sex = 1 if (tsex==101 | tsex==102) & tt== 305
replace sex = 2 if (tsex==201 | tsex==202) & tt== 305
* -------------------------------------
* tt = 45
replace sex = 1 if (tsex==11 | tsex==12) & tt== 45
replace sex = 2 if (tsex==21 | tsex==22) & tt== 45
* -------------------------------------
* 1x befragt
replace sex = 1 if tsex==1    & tt==   5
replace sex = 2 if tsex==2    & tt==   5
replace sex = 1 if tsex==10   & tt==  40
replace sex = 2 if tsex==20   & tt==  40
replace sex = 1 if tsex==100  & tt== 300
replace sex = 2 if tsex==200  & tt== 300
replace sex = 1 if tsex==1000 & tt==2000
replace sex = 2 if tsex==2000 & tt==2000

* -------------------------------------------------------

lab var sex "Geschlecht - längsschnittkonsistent" 
lab def sex 1 "männlich" 2 "weiblich" //  "." Ausfallsätze
numlabel sex, add mask("[#] ") force 
lab val sex sex
* format sex %1.0f

* Kontrollen
* tab ausftyp ef46  if sex==., m
* tab sex, m
* tab ausftyp if sex==.

* Hilfsvariablen löschen
drop sex_1 sex_2 sex_3 sex_4 tsex1 tsex2 tsex3 tsex4 tsex

* =============================================================================

* gebj <- Geburtsjahr längsschnittkonsistent

/* Codierungen in den Datenhandbüchern (DHB)
   DHB 2012           | DHB 2013              | DHB 2014              | DHB 2015              |
Code Val Lab          | Code Val Lab          | Code Val Lab          | Code Val Lab          |
----------------------+-----------------------+-----------------------+-----------------------+
1909 1910 oder früher |                       |                       |                       |
1912 1911 oder 1912   | 1912 1912 oder früher | 1912 1912 oder früher |1912 1912 oder früher  |
1913 1913             | 1913 1913             |                       |                       |
1914 1914             | 1914 1914             | 1914 1914 oder 1913   |1914 1914 oder 1913    |
1915 1915             | 1915 1915             | 1915 1915             |                       |
1916 1916             | 1916 1916             | 1916 1916             |1916 1916 oder 1915    |
(...)                 | (...)                 | (...)                 | (...)                 |
2012 2012             | 2012 2012             | 2012 2012             | 2012 2012             | 
                      | 2013 2013             | 2013 2013             | 2013 2013             |
                      |                       | 2014 2014             | 2014 2014             |
                      |                       |                       | 2015 2015             |
==> zusammenfassen 1909/1916					  
*/

* gebj_* <- gültige Angaben in ef47 Geburtsjahr (2012: Ausfallsätze haben gültige Angaben in ef47!)
gen gebj_1 = ef47 * (ef47>=1909 & ef47<=2015 & r1==1)
gen gebj_2 = ef47 * (ef47>=1909 & ef47<=2015 & r2==1)
gen gebj_3 = ef47 * (ef47>=1909 & ef47<=2015 & r3==1)
gen gebj_4 = ef47 * (ef47>=1909 & ef47<=2015 & r4==1)
recode gebj_1 gebj_2 gebj_3 gebj_4 (1909/1916=1916) // 1916 oder früher geboren
format gebj_1 gebj_2 gebj_3 gebj_4 %04.0f

egen double tgebj1 = total(gebj_1), by(idpers)
egen double tgebj2 = total(gebj_2), by(idpers)
egen double tgebj3 = total(gebj_3), by(idpers)
egen double tgebj4 = total(gebj_4), by(idpers)
format tgebj1 tgebj2 tgebj3 tgebj4 %04.0f

* tt=2345 4x befragt, 4x übereinstimmend
gen gebj = tgebj1 if tt==2345 & tgebj1==tgebj2 & tgebj1==tgebj3 & tgebj1==tgebj4
*                     3x übereinstimmend
replace gebj = tgebj1 if tt==2345 & gebj==. & tgebj1==tgebj2 & tgebj1==tgebj3
replace gebj = tgebj1 if tt==2345 & gebj==. & tgebj1==tgebj2 & tgebj1==tgebj4
replace gebj = tgebj1 if tt==2345 & gebj==. & tgebj1==tgebj3 & tgebj1==tgebj4
replace gebj = tgebj2 if tt==2345 & gebj==. & tgebj2==tgebj3 & tgebj2==tgebj4
*                     2x übereinstimmend, 2 andere nicht übereinstimmend
replace gebj = tgebj1 if tt==2345 & gebj==. & tgebj1==tgebj2 & tgebj3!=tgebj4
replace gebj = tgebj1 if tt==2345 & gebj==. & tgebj1==tgebj3 & tgebj2!=tgebj4
replace gebj = tgebj2 if tt==2345 & gebj==. & tgebj2==tgebj3 & tgebj1!=tgebj4
replace gebj = tgebj3 if tt==2345 & gebj==. & tgebj3==tgebj4 & tgebj1!=tgebj2
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2345 & gebj==.

count if tt==2345 & gebj_1!=gebj_2 & gebj_1!=gebj_3 & gebj_1!=gebj_4 //   88.087
count if tt==2345 & tgebj1!=tgebj2 & tgebj1!=tgebj3 & tgebj1!=tgebj4 //    4.820

* ------------------------------------------------------------------
* tt =  2340 3x befragt, 3x übereinstimmend
replace gebj = tgebj1 if tt==2340 & gebj==. & tgebj1==tgebj2 & tgebj1==tgebj3
*                        2x übereinstimmend
replace gebj = tgebj1 if tt==2340 & gebj==. & tgebj1==tgebj2 
replace gebj = tgebj1 if tt==2340 & gebj==. & tgebj1==tgebj3
replace gebj = tgebj2 if tt==2340 & gebj==. & tgebj2==tgebj3
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2340 & gebj==.
* ------------------------------------------------------------------------
* tt=2305 3x befragt, 3x übereinstimmend
replace gebj = tgebj1 if tt==2305 & gebj==. & tgebj1==tgebj2 & tgebj1==tgebj4
*                        2x übereinstimmend
replace gebj = tgebj1 if tt==2305 & gebj==. & tgebj1==tgebj2 
replace gebj = tgebj1 if tt==2305 & gebj==. & tgebj1==tgebj4
replace gebj = tgebj2 if tt==2305 & gebj==. & tgebj2==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2305 & gebj==.
* ------------------------------------------------------------------------------
* tt=2045 3x befragt, 3x übereinstimmend
replace gebj = tgebj1 if tt==2045 & gebj==. & tgebj1==tgebj3 & tgebj1==tgebj4
*                        2x übereinstimmend
replace gebj = tgebj1 if tt==2045 & gebj==. & tgebj1==tgebj3 
replace gebj = tgebj1 if tt==2045 & gebj==. & tgebj1==tgebj4
replace gebj = tgebj3 if tt==2045 & gebj==. & tgebj3==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2045 & gebj==.
* ------------------------------------------------------------------------------
* tt= 345 3x befragt, 3x übereinstimmend
replace gebj = tgebj2 if tt== 345 & gebj==. & tgebj2==tgebj3 & tgebj2==tgebj4
*                        2x übereinstimmend
replace gebj = tgebj2 if tt== 345 & gebj==. & tgebj2==tgebj3 
replace gebj = tgebj2 if tt== 345 & gebj==. & tgebj2==tgebj4 
replace gebj = tgebj3 if tt== 345 & gebj==. & tgebj3==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj2 if tt== 345 & gebj==.
* ------------------------------------------------------------------------------
* tt=2300 2x befragt
replace gebj = tgebj1 if tt==2300 & gebj==. & tgebj1==tgebj2
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2300 & gebj==.
* ------------------------------------------------------------------------------
* tt=2040 2x befragt
replace gebj = tgebj1 if tt==2040 & gebj==. & tgebj1==tgebj3
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2040 & gebj==.
* ------------------------------------------------------------------------------
* tt=2005 2x befragt 
replace gebj = tgebj1 if tt==2005 & gebj==. & tgebj1==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj1 if tt==2005 & gebj==.
* ------------------------------------------------------------------------------
* tt= 340, 2x befragt
replace gebj = tgebj2 if tt== 340 & gebj==. & tgebj2==tgebj3
* Rest: 1. Angabe
replace gebj = tgebj2 if tt== 340 & gebj==.
* ------------------------------------------------------------------------------
* tt=305. 2x befragt
replace gebj = tgebj2 if tt== 305 & gebj==. & tgebj2==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj2 if tt== 305 & gebj==.
* ------------------------------------------------------------------------------
* tt=45 2x befragt
replace gebj = tgebj3 if tt== 45 & gebj==. & tgebj3==tgebj4
* Rest: 1. Angabe
replace gebj = tgebj3 if tt== 45 & gebj==.
* ------------------------------------------------------------------------------
* Rest: 1x befragt
replace gebj = tgebj4 if tt==   5 & gebj==.
replace gebj = tgebj3 if tt==  40 & gebj==.
replace gebj = tgebj2 if tt== 300 & gebj==.
replace gebj = tgebj1 if tt==2000 & gebj==.
* ------------------------------------------------------------------------------

lab var gebj "Geburtsjahr - längsschnittkonsistent" 
lab def gebj 1916 "1916 oder früher" //  "." Ausfallsätze
lab val gebj gebj
* numlabel gebj, add mask("[#] ") force 
* format gebj %4.0f

* Kontrollen
* tab gebj t, m
/*  Geburtsjahr - |
 längsschnittkons |                Panelzeitpukt
           istent |  [1] 2012   [2] 2013   [3] 2014   [4] 2015 |     Total
------------------+--------------------------------------------+----------
 1916 oder früher |       571        377        222        140 |      1310 
             1917 |       163        117         87         63 |       430 
(...)        
             2011 |      3703       3768       3862       3820 |     15153 
             2012 |      1919       3764       3858       3848 |     13389 
             2013 |         3       2001       3784       3870 |      9658 ! Jahresüberhänge t=2012 <-> max(gebj)=2013
             2014 |         0         18       2057       3757 |      5832 ! Jahresüberhänge t=2013 <-> max(gebj)=2014
             2015 |         0          0          9       1935 |      1944 ! Jahresüberhänge t=2014 <-> max(gebj)=2015
                . |     30155      45691      50319      47440 |    173605 
------------------+--------------------------------------------+----------
            Total |    514567     527899     527606     511003 |   2081075  */

* tab gebj sex, m

* Hilfsvariablen löschen
drop gebj_1 gebj_2 gebj_3 gebj_4  tgebj1 tgebj2 tgebj3 tgebj4 tt tx1-tx4 

* Response-Variablen löschen, werden mit Programm prog_2a.do neu erstellt
drop r1 r2 r3 r4

compress

save "panel_v1d.dta", replace

log close
