* prog_2b.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns


Erstellung neuer Typisierungen
att         Teilnahme-/Ausfallmuster (attrition) <- ausftyp & rot 
r*          Response gültige Personenangaben für Zeitpunkt t 
r*rot*_psu  Response | psu: 0=Ausfall ganzer Auswahlbez. 1=gültige Ang. vorh.
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using prog_2b.log, text

* erstellt mit prog_2a.do
use panel_v2a.dta, replace


* Zuordnung zum Teilnahme-/Ausfallmuster nach ausftyp = "ptyp | ptyp_psu"
*    und rot Rotationsgruppe (Proxy)
gen att = 0
lab var att "Teilnahme-/Ausfallmuster (attrition) <- ausftyp & rot" 
* att = [-1] Ausfallsatz
replace att = -1 if att==0 & ausftyp==-1 // [-1] Ausfallsatz 
* att = [0] Teilnahme                        ausftyp          rot  
replace att =  0 if ausftyp== 1 & rot==73 //  [1] 2---|2--- & [73] 09-12 
replace att =  0 if ausftyp== 2 & rot==74 //  [2] 23--|23-- & [74] 10-13
replace att =  0 if ausftyp== 3 & rot==81 //  [3] 234-|234- & [81] 11-14
replace att =  0 if ausftyp== 0 & rot==82 //  [0] 2345|2345 & [82] 12-15
replace att =  0 if ausftyp== 7 & rot==83 //  [7] -345|-345 & [83] 13-15
replace att =  0 if ausftyp==10 & rot==84 // [10] --45|--45 & [84] 14-15
replace att =  0 if ausftyp==11 & rot==91 // [11] ---5|---5 & [91] 15-15
* att = [1] Ausfall verschachtelt mit Teilnahme (attrition)
*           Sonstige Ausfälle auf PSU-Ebene werden nicht berücksichtigt.
replace att =  1 if ausftyp== 1 & rot>=74 & rot<=82 //  [1] 2---|2--- 
replace att =  1 if ausftyp== 2 & rot>=81 & rot<=82 //  [2] 23--|23--
replace att =  1 if ausftyp== 3 & rot==82           //  [3] 234-|234-
replace att =  1 if ausftyp== 5 & rot==83           //  [5] -3--|-3--
replace att =  1 if ausftyp== 6 & rot==83           //  [6] -34-|-34-
replace att =  1 if ausftyp== 9 & rot==84           //  [9] --4-|--4-
replace att =  1 if ausftyp==12 & rot>=74 & rot<=82 // [12] 2---|23--
replace att =  1 if ausftyp==13 & rot>=81 & rot<=82 // [13] 2---|234-
replace att =  1 if ausftyp==14 & rot==82           // [14] 2---|23-5
replace att =  1 if ausftyp==15 & rot==81           // [15] 2---|2-4-
replace att =  1 if ausftyp==16 & rot>=81 & rot<=82 // [16] 23--|234-
replace att =  1 if ausftyp==17 & rot==82           // [17] 23--|23-5
replace att =  1 if ausftyp==18 & rot==83           // [18] -3--|-34-
replace att =  1 if ausftyp==19 & rot==83           // [19] -3--|-345
replace att =  1 if ausftyp==20 & rot==83           // [20] -3--|-3-5
replace att =  1 if ausftyp==21 & rot==83           // [21] -34-|-345
replace att =  1 if ausftyp==22 & rot==84           // [22] --4-|--45
replace att =  1 if ausftyp==23 & rot==82           // [23] 2---|2345
replace att =  1 if ausftyp==24 & rot==82           // [24] 23--|2345
replace att =  1 if ausftyp==25 & rot==82           // [25] 234-|2345
* att = [2] Wiedereintritt, temporärer Ausfall
replace att =  2 if ausftyp== 4 & rot==82           //  [4] 23-5|23-5
replace att =  2 if ausftyp== 8 & rot==83           //  [8] -3-5|-3-5
replace att =  2 if ausftyp==26 & rot==82           // [26] 23-5|2345
replace att =  2 if ausftyp==27 & rot==82           // [27] 2-4-|2345
replace att =  2 if ausftyp==28 & rot>=81 & rot<=82 // [28] 2-4-|234-
replace att =  2 if ausftyp==29 & rot==82           // [29] 2-45|2345
replace att =  2 if ausftyp==30 & rot==82           // [30] 2--5|2345
replace att =  2 if ausftyp==38 & rot==82           // [38] -3-5|2345
replace att =  2 if ausftyp==39 & rot==83           // [39] -3-5|-345
* att = [3] Späteintritt (Zuzug, Geburt) (late entry)
replace att =  3 if ausftyp== 5 & rot>=74 & rot<=82 // [5] -3--|-3--
replace att =  3 if ausftyp== 6 & rot>=81 & rot<=82 // [6] -34-|-34-
replace att =  3 if ausftyp== 7 & rot==82           // [7] -345|-345
replace att =  3 if ausftyp== 9 & rot>=81 & rot<=83 // [9] --4-|--4-
replace att =  3 if ausftyp==10 & rot>=82 & rot<=83 // [10] --45|--45
replace att =  3 if ausftyp==11 & rot>=82 & rot<=84 // [11] ---5|---5 
replace att =  3 if ausftyp==18 & rot>=81 & rot<=82 // [18] -3--|-34-
replace att =  3 if ausftyp==19 & rot==82           // [19] -3--|-345
replace att =  3 if ausftyp==21 & rot==82           // [21] -34-|-345
replace att =  3 if ausftyp==22 & rot>=82 & rot<=83 // [22] --4-|--45  
replace att =  3 if ausftyp==31 & rot==82           // [31] -3--|2345 
replace att =  3 if ausftyp==32 & rot>=74 & rot<=82 // [32] -3--|23-- 
replace att =  3 if ausftyp==33 & rot>=81 & rot<=82 // [33] -3--|234- 
replace att =  3 if ausftyp==34 & rot==82           // [34] -3--|23-5 
replace att =  3 if ausftyp==35 & rot==82           // [35] -34-|2345 
replace att =  3 if ausftyp==36 & rot>=81 & rot<=82 // [36] -34-|234- 
replace att =  3 if ausftyp==37 & rot==82           // [37] -345|2345
replace att =  3 if ausftyp==40 & rot==82           // [40] --4-|2345 
replace att =  3 if ausftyp==41 & rot>=81 & rot<=82 // [41] --4-|234- 
replace att =  3 if ausftyp==42 & rot==81           // [42] --4-|2-4- 
replace att =  3 if ausftyp==43 & rot>=81 & rot<=83 // [43] --4-|-34- 
replace att =  3 if ausftyp==44 & rot>=82 & rot<=83 // [44] --4-|-345 
replace att =  3 if ausftyp==45 & rot==82           // [45] --45|2345
replace att =  3 if ausftyp==46 & rot>=82 & rot<=83 // [46] --45|-345 
replace att =  3 if ausftyp==47 & rot==82           // [47] ---5|2345 
replace att =  3 if ausftyp==48 & rot==82           // [48] ---5|23-5 
replace att =  3 if ausftyp==49 & rot>=82 & rot<=83 // [49] ---5|-345 
replace att =  3 if ausftyp==50 & rot>=82 & rot<=83 // [50] ---5|-3-5
replace att =  3 if ausftyp==51 & rot>=82 & rot<=84 // [51] ---5|--45 
lab def att -1 "Ausfallsatz" ///
             0 "Teilnahme" /// response
             1 "Ausfall (verschachtelt mit Teilnahme)" /// attrition
             2 "Wiedereintritt, temporärer Ausfall" /// re-entry
             3 "Späteintritt", add modify // late entry
numlabel att , add mask("[#] ") force
lab val att att

* Kontrollen
* tab att rot if att>=0, m nofreq col
* tab ausftyp att if rot==82, m

* ------------------------------------------------------------------------------

* Response Variablen ~t*~  1 = gültige Personenangaben
gen byte r1 = (ef46_1>=1 & ef46_1<=2) 
gen byte r2 = (ef46_2>=1 & ef46_2<=2) 
gen byte r3 = (ef46_3>=1 & ef46_3<=2) 
gen byte r4 = (ef46_4>=1 & ef46_4<=2) 

lab var r1 "Response gültige Angaben - t1"
lab var r2 "Response gültige Angaben - t2"
lab var r3 "Response gültige Angaben - t3"
lab var r4 "Response gültige Angaben - t4"
lab def r 0 "nein" 1 "ja"
numlabel r, add mask("[#] ") force
lab val r1 r
lab val r2 r
lab val r3 r
lab val r4 r

* ------------------------------------------------------------------------------

* Response | psu : Anzahl gültiger Personenangaben im Auswahlbezirk recodiert
*    0=Ausfall ganzer Auswahlbezirke  1=gültige Angaben vorhanden
egen r1_rot73_psu = total(r1==1 & rot==73), by(idpsu)
egen r2_rot73_psu = total(r2==1 & rot==73), by(idpsu)
egen r3_rot73_psu = total(r3==1 & rot==73), by(idpsu)
egen r4_rot73_psu = total(r4==1 & rot==73), by(idpsu)
recode r*_rot73_psu (0=0) (1/999=1)

egen r1_rot74_psu = total(r1==1 & rot==74), by(idpsu)
egen r2_rot74_psu = total(r2==1 & rot==74), by(idpsu)
egen r3_rot74_psu = total(r3==1 & rot==74), by(idpsu)
egen r4_rot74_psu = total(r4==1 & rot==74), by(idpsu)
recode r*_rot74_psu (0=0) (1/999=1)

egen r1_rot81_psu = total(r1==1 & rot==81), by(idpsu)
egen r2_rot81_psu = total(r2==1 & rot==81), by(idpsu)
egen r3_rot81_psu = total(r3==1 & rot==81), by(idpsu)
egen r4_rot81_psu = total(r4==1 & rot==81), by(idpsu)
recode r*_rot81_psu (0=0) (1/999=1)

egen r1_rot82_psu = total(r1==1 & rot==82), by(idpsu)
egen r2_rot82_psu = total(r2==1 & rot==82), by(idpsu)
egen r3_rot82_psu = total(r3==1 & rot==82), by(idpsu)
egen r4_rot82_psu = total(r4==1 & rot==82), by(idpsu)
recode r*_rot82_psu (0=0) (1/999=1)

egen r1_rot83_psu = total(r1==1 & rot==83), by(idpsu)
egen r2_rot83_psu = total(r2==1 & rot==83), by(idpsu)
egen r3_rot83_psu = total(r3==1 & rot==83), by(idpsu)
egen r4_rot83_psu = total(r4==1 & rot==83), by(idpsu)
recode r*_rot83_psu (0=0) (1/999=1)

egen r1_rot84_psu = total(r1==1 & rot==84), by(idpsu)
egen r2_rot84_psu = total(r2==1 & rot==84), by(idpsu)
egen r3_rot84_psu = total(r3==1 & rot==84), by(idpsu)
egen r4_rot84_psu = total(r4==1 & rot==84), by(idpsu)
recode r*_rot84_psu (0=0) (1/999=1)

egen r1_rot91_psu = total(r1==1 & rot==91), by(idpsu)
egen r2_rot91_psu = total(r2==1 & rot==91), by(idpsu)
egen r3_rot91_psu = total(r3==1 & rot==91), by(idpsu)
egen r4_rot91_psu = total(r4==1 & rot==91), by(idpsu)
recode r*_rot91_psu (0=0) (1/999=1)

lab var r1_rot73_psu "Response % Befragte | rot=73, t1"
lab var r2_rot73_psu "Response % Befragte | rot=73, t2"
lab var r3_rot73_psu "Response % Befragte | rot=73, t3"
lab var r4_rot73_psu "Response % Befragte | rot=73, t4"

lab var r1_rot74_psu "Response % Befragte | rot=74, t1"
lab var r2_rot74_psu "Response % Befragte | rot=74, t2"
lab var r3_rot74_psu "Response % Befragte | rot=74, t3"
lab var r4_rot74_psu "Response % Befragte | rot=74, t4"

lab var r1_rot81_psu "Response % Befragte | rot=81, t1"
lab var r2_rot81_psu "Response % Befragte | rot=81, t2"
lab var r3_rot81_psu "Response % Befragte | rot=81, t3"
lab var r4_rot81_psu "Response % Befragte | rot=81, t4"

lab var r1_rot82_psu "Response % Befragte | rot=82, t1"
lab var r2_rot82_psu "Response % Befragte | rot=82, t2"
lab var r3_rot82_psu "Response % Befragte | rot=82, t3"
lab var r4_rot82_psu "Response % Befragte | rot=82, t4"

lab var r1_rot83_psu "Response % Befragte | rot=83, t1"
lab var r2_rot83_psu "Response % Befragte | rot=83, t2"
lab var r3_rot83_psu "Response % Befragte | rot=83, t3"
lab var r4_rot83_psu "Response % Befragte | rot=83, t4"

lab var r1_rot84_psu "Response % Befragte | rot=84, t1"
lab var r2_rot84_psu "Response % Befragte | rot=84, t2"
lab var r3_rot84_psu "Response % Befragte | rot=84, t3"
lab var r4_rot84_psu "Response % Befragte | rot=84, t4"

lab var r1_rot91_psu "Response % Befragte | rot=91, t1"
lab var r2_rot91_psu "Response % Befragte | rot=91, t2"
lab var r3_rot91_psu "Response % Befragte | rot=91, t3"
lab var r4_rot91_psu "Response % Befragte | rot=91, t4"

lab def r_rot_psu 0 "keine gültigen Angaben" 1 "1+ gültige Angaben"
numlabel r_rot_psu, add mask("[#] ") force
for var r*_psu : lab val X r_rot_psu

* Kontrollen
* tabstat r1_rot73_psu r2_rot73_psu r3_rot73_psu r4_rot73_psu if rot==73, s(count mean) by(ptyp)
* (...)

* Rotationsgruppe 83 (in Stichprobe 2013-2015) enthält überdurchschnittlich 
*   viele Ausfälle und "Späteintritte"; auch auf Ebene der Auswahlbezirke
* tab rot att, row

* tabstat r1_rot83_psu r2_rot83_psu r3_rot83_psu r4_rot83_psu if rot==83, s(count mean) by(att)

* ------------------------------------------------------------------------------

save "panel_v2b.dta", replace

log close

