* prog_2c.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns

Näherungsweise Ermittlung der Ausfallgründe. 
Vorbereitung für gemeinsame Analysen mit MZ-Panel 2001-2004.
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using prog_2c.log, text

* erstellt mit prog_2b.do
use "panel_v2b.dta", replace

/* Näherungsweise Ermittlung der Ausfallgründe in Anlehnung an Typisierungen 
   der früheren MZ-Panels 1996-1999 und 2001-2004 
verlustp  Art des Verlusts auf der Personenebene (Fortzug vs. Sterbefall)
[gewinnp  Art des Zugewinns auf der Personenebene (Zuzug vs. Geburt)
          siehe am Ende der Datei] 

Neu erstellt 
   diff_hhgr Differenz Anzahl HH-Mitglieder (t-1) - (t)
*/

* Übergang 2012 -> 2013
* "Verluste": Personen mit gültigen Angaben zum Geschlecht 2012, aber nicht 2013
egen pverl_2 = total(r1==1 & r2==0), by(idpers_n)
lab var pverl_2 "Ausfall Person 2012->2013"

* "Gewinne": Personen ohne gültigen Angaben zum Geschlecht 2012, aber 2013
egen pgew_2 = total(r1==0 & r2==1), by(idpers_n)
lab var pgew_2 "Zugang Person 2012->2013"

* Anzahl "Verluste" im Haushalt (incl. Gem.unterk.)
egen pverl_h_2 = total(pverl_2), by(idhh)
lab var pverl_h_2 "Anzahl ausgef. Personen 12->13 | idhh"

* Anzahl "Gewinne" (Geburten oder Zuzüge) im Haushalt (incl. Gem.unterk.)
egen pgew_h_2 = total(pgew_2), by(idhh)
lab var pgew_h_2 "Anzahl zugez. Personen 12->13 | idhh"

* Anzahl HH-Mitglieder (incl. Gem.unterk.)
egen nh_1  = total(r1==1), by(idhh)
lab var nh_1   "n Personen | idhh - t1"
egen nh_2  = total(r2==1), by(idhh)
lab var nh_2   "n Personen | idhh - t2"
gen  nh_diff_2 = nh_1 - nh_2
lab var nh_diff_2 "diff n nh_1 - nh_2"

* Ausfall ganzer Haushalt, keine Zugänge/Gewinne 
gen hhausf_2 = (nh_diff_2==nh_1 & pgew_h_2==0) if r1==1 & r2>=0 & r2<=1
lab var hhausf_2 "vollst. Ausfall HH/GU 2012->13"
lab def hhausf 0 "nein" 1 "ja"
numlabel hhausf, add mask("[#] ") force
lab val hhausf_2 hhausf

* Initialisierung verlust_2 "Art Verluste Übergang 2012->2013"
gen verlust_2 = 9 if r1==1 & r2==0
replace verlust_2 = -2 if verlust_2==9 & rot==73
replace verlust_2 =  3 if verlust_2==9 & hhausf_2==1
lab var verlust_2 "Art Verluste Übergang 2012->2013"
lab def verlust -2 "ROT letztmals in Stichprobe" 
                 3 "Fortzug ganzer Haushalt ohne Angaben zum Ausfallgrund" ///
                 9 "Nicht zuordenbare Ausfälle", add modify // nicht differenzierbar: 1 "Tod einer Person" 2 "Fortzug einer Person"
numlabel verlust, add mask("[#] ") force
lab val verlust_2 verlust

tab verlust_2 r2 if r1==1 & rot==82 & att>=0 & att<=1, m
/*
                      |   Response gültige
         Art Verluste |     Angaben - t2
  Übergang 2012->2013 |  [0] nein     [1] ja |     Total
----------------------+----------------------+----------
[4] Fortzug ganzer HH |      9712          0 |      9712 
[9] Nicht zuordenbare |      3285          0 |      3285 
                    . |         0     107948 |    107948 
----------------------+----------------------+----------
                Total |     12997     107948 |    120945
*/

* diff_hhgr Differenz Anzahl HH-Mitglieder (t-1) - (t)
gen byte hhgr_diff_2 = 0 if r1==1 & r2==0 & att==1                                               // Ausfall verschachtelt mit Teilnahme
replace  hhgr_diff_2 = 1 if nh_diff_2<0               & pgew_h_2>0  & pgew_h_2<. & r1==1 & r2==0 // Zuzug
replace  hhgr_diff_2 = 2 if nh_diff_2==0              & pgew_h_2>0  & pgew_h_2<. & r1==1 & r2==0 // Zuzug
replace  hhgr_diff_2 = 3 if nh_diff_2> 0              & pgew_h_2>0  & pgew_h_2<. & r1==1 & r2==0 // Zuzug
replace  hhgr_diff_2 = 4 if            nh_1 > nh_2    & pgew_h_2==0              & r1==1 & r2==0 // Teilausfall ohne Zuzug
replace  hhgr_diff_2 = 5 if nh_diff_2==nh_1 & nh_2==0 & pgew_h_2==0              & r1==1 & r2==0 // HH/GU vollst. ausgef. & kein Zuzug 12->13
* tab hhgr_diff_2 verlust_2 if r1==1 & r2==0 & rot==82 & att==1, m
recode  hhgr_diff_2 (1/4=1) (5=4)
replace hhgr_diff_2 = 0 if hhgr_diff_2==1 & nh_diff_2<=0
replace hhgr_diff_2 = 1 if hhgr_diff_2==1 & nh_diff_2==1
replace hhgr_diff_2 = 2 if hhgr_diff_2==1 & nh_diff_2==2
replace hhgr_diff_2 = 3 if hhgr_diff_2==1 & nh_diff_2>=3 & nh_diff_2<.
lab var hhgr_diff_2 "Diff. hhgr (t1) - hhgr (t2): vor Ausfall"
lab def hhgr_diff 0 "<=0 Zuzug" 1 "1 Ausfall" 2 "2 Ausfälle" 3 "3+ Ausfälle" 4 "HH/GU ganz ausgef.", add modify
numlabel hhgr_diff, add mask("[#] ") force
lab val hhgr_diff_2 hhgr_diff
lab var hhgr_diff_2 "Diff. hhgr (t-1) - hhgr (t) 2012->2013"
tab hhgr_diff_2 if r1==1 & r2==0 & rot==82 & att==1 & verlust_2!=3

* ------------------------------------------------------------------------------

* Übergang 2013->2014
* "Verluste": Personen mit gültigen Angaben zum Geschlecht 2013, aber nicht 2014
egen pverl_3 = total(r2==1 & r3==0), by(idpers_n)
lab var pverl_3 "Ausfall Person 2013->2014"

* "Gewinne": Personen ohne gültigen Angaben zum Geschlecht 2013, aber 2014
egen pgew_3 = total(r2==0 & r3==1), by(idpers_n)
lab var pgew_3 "Zugang Person 2013->2014"

* Anzahl Verluste 2013->2014 im Haushalt (incl. Gem.unterk.)
egen pverl_h_3 = total(pverl_3), by(idhh)
lab var pverl_h_3 "Anzahl ausgef. Personen 13->14 | idhh"

* Anzahl Gewinne (Geburten oder Zuzüge) 2013->2014 im Haushalt
egen pgew_h_3 = total(pgew_3), by(idhh)
lab var pgew_h_3 "Anzahl zugez. Personen 13->14 | idhh"

* Anzahl HH-Mitglieder 2013 und 2014 im Haushalt
* egen nh_2  = total(r2==1), by(idhh)
* lab var nh_2   "n Personen | idhh - t2"

egen nh_3  = total(r3==1), by(idhh)
lab var nh_3   "n Personen | idhh - t3"

gen  nh_diff_3 = nh_2 - nh_3
lab var nh_diff_3 "diff n nh_2 - nh_3"

* Ausfall ganzer Haushalt, keine Zugänge/Gewinne
gen hhausf_3 = (nh_diff_3==nh_2 & pgew_h_3==0) if r2==1 & r3>=0 & r3<=1
lab var hhausf_3 "vollst. Ausfall HH/GU 2013->14"
* lab def hhausf 0 "nein" 1 "ja"
* numlabel hhausf, add mask("[#] ") force
lab val hhausf_3 hhausf

* Initialisierung verlust_3 "Art Verluste Übergang 2013->2014"
gen verlust_3 = 9 if r2==1 & r3==0
replace verlust_3 = -2 if verlust_3==9 & rot==74
replace verlust_3 =  3 if verlust_3==9 & hhausf_3==1
lab var verlust_3 "Art Verluste Übergang 2013->2014"
lab val verlust_3 verlust

tab verlust_3 r3 if r1==1 & r2==1 & rot==82 & att>=0 & att<=1, m
/*
                      |   Response gültige
         Art Verluste |     Angaben - t3
  Übergang 2013->2014 |  [0] nein     [1] ja |     Total
----------------------+----------------------+----------
[4] Fortzug ganzer HH |      7337          0 |      7337 
[9] Nicht zuordenbare |      2647          0 |      2647 
                    . |         0      97964 |     97964 
----------------------+----------------------+----------
                Total |      9984      97964 |    107948 
*/

* diff_hhgr Differenz Anzahl HH-Mitglieder (t-1) - (t)
gen byte hhgr_diff_3 = 0 if r2==1 & r3==0 & att==1
replace  hhgr_diff_3 = 1 if nh_diff_3<0               & pgew_h_3>0  & pgew_h_3<. & r2==1 & r3==0
replace  hhgr_diff_3 = 2 if nh_diff_3==0              & pgew_h_3>0  & pgew_h_3<. & r2==1 & r3==0
replace  hhgr_diff_3 = 3 if nh_diff_3> 0              & pgew_h_3>0  & pgew_h_3<. & r2==1 & r3==0
replace  hhgr_diff_3 = 4 if            nh_2 > nh_3    & pgew_h_3==0              & r2==1 & r3==0
replace  hhgr_diff_3 = 5 if nh_diff_3==nh_2 & nh_3==0 & pgew_h_3==0              & r2==1 & r3==0
recode  hhgr_diff_3 (1/4=1) (5=4)
replace hhgr_diff_3 = 0 if hhgr_diff_3==1 & nh_diff_3<=0
replace hhgr_diff_3 = 1 if hhgr_diff_3==1 & nh_diff_3==1
replace hhgr_diff_3 = 2 if hhgr_diff_3==1 & nh_diff_3==2
replace hhgr_diff_3 = 3 if hhgr_diff_3==1 & nh_diff_3>=3 & nh_diff_3<.
lab var hhgr_diff_3 "Diff. hhgr (t-1) - hhgr (t) 2013->2014"
* lab def hhgr_diff 0 "<=0 Zuzug" 1 "1 Ausfall" 2 "2 Ausfälle" 3 "3+ Ausfälle" 4 "HH/GU ganz ausgef.", add modify
* numlabel hhgr_diff, add mask("[#] ") force
lab val hhgr_diff_3 hhgr_diff

* ------------------------------------------------------------------------------

* Übergang 2014->2015
* "Verluste": Personen mit gültigen Angaben zum Geschlecht 2014, aber nicht 2015
egen pverl_4 = total(r3==1 & r4==0), by(idpers_n)
lab var pverl_4 "Ausfall Person 2014->2015"

* "Gewinne": Personen ohne gültigen Angaben zum Geschlecht 2014, aber 2015
egen pgew_4 = total(r3==0 & r4==1), by(idpers_n)
lab var pgew_4 "Zugang Person 2014->2015"

* Anzahl Verluste 2014->2015 im Haushalt (incl. Gem.unterk.)
egen pverl_h_4 = total(pverl_4), by(idhh)
lab var pverl_h_4 "Anzahl ausgef. Personen 14->15 | idhh"

* Anzahl Gewinne (Geburten oder Zuzüge) 2014->2015 im Haushalt
egen pgew_h_4 = total(pgew_4), by(idhh)
lab var pgew_h_4 "Anzahl zugez. Personen 14->15 | idhh"

* Anzahl HH-Mitglieder 2014 und 2015 im Haushalt
* egen nh_3  = total(r3==1), by(idhh)
* lab var nh_3   "n Personen | idhh - t3"

egen nh_4  = total(r4==1), by(idhh)
lab var nh_4   "n Personen | idhh - t4"

gen  nh_diff_4 = nh_3 - nh_4
lab var nh_diff_4 "diff n nh_3 - nh_4"

* Ausfall ganzer Haushalt, keine Zugänge/Gewinne 
gen hhausf_4 = (nh_diff_4==nh_3 & pgew_h_4==0) if r3==1 & r4>=0 & r4<=1
lab var hhausf_4 "vollst. Ausfall HH/GU 2014->15"
lab val hhausf_4 hhausf

* Initialisierung verlust_4 "Art Verluste Übergang 2014->2015"
gen verlust_4 = 9 if r3==1 & r4==0
replace verlust_4 = -2 if verlust_4==9 & rot==81	
replace verlust_4 = 3 if verlust_4==9 & hhausf_4==1
lab var verlust_4 "Art Verluste Übergang 2014->2015"
lab val verlust_4 verlust

tab verlust_4 r4 if r1==1 & r2==1 & r3==1 & rot==82 & att>=0 & att<=1, m
/*
                      |   Response gültige
         Art Verluste |     Angaben - t4
  Übergang 2014->2015 |  [0] nein     [1] ja |     Total
----------------------+----------------------+----------
[4] Fortzug ganzer HH |      7631          0 |      7631 
[9] Nicht zuordenbare |      2246          0 |      2246 
                    . |         0      88087 |     88087 
----------------------+----------------------+----------
                Total |      9877      88087 |     97964
*/

* diff_hhgr Differenz Anzahl HH-Mitglieder (t-1) - (t)
gen byte hhgr_diff_4 = 0 if r3==1 & r4==0 & att==1
replace  hhgr_diff_4 = 1 if nh_diff_4<0               & pgew_h_4>0  & pgew_h_4<. & r3==1 & r4==0
replace  hhgr_diff_4 = 2 if nh_diff_4==0              & pgew_h_4>0  & pgew_h_4<. & r3==1 & r4==0
replace  hhgr_diff_4 = 3 if nh_diff_4> 0              & pgew_h_4>0  & pgew_h_4<. & r3==1 & r4==0
replace  hhgr_diff_4 = 4 if            nh_2 > nh_3    & pgew_h_4==0              & r3==1 & r4==0
replace  hhgr_diff_4 = 5 if nh_diff_4==nh_3 & nh_4==0 & pgew_h_4==0              & r3==1 & r4==0
recode  hhgr_diff_4 (1/4=1) (5=4)
replace hhgr_diff_4 = 0 if hhgr_diff_4==1 & nh_diff_4<=0
replace hhgr_diff_4 = 1 if hhgr_diff_4==1 & nh_diff_4==1
replace hhgr_diff_4 = 2 if hhgr_diff_4==1 & nh_diff_4==2
replace hhgr_diff_4 = 3 if hhgr_diff_4==1 & nh_diff_4>=3 & nh_diff_4<.
lab var hhgr_diff_4 "Diff. hhgr (t-1) - hhgr (t) 2014->2015"
* lab def hhgr_diff 0 "<=0 Zuzug" 1 "1 Ausfall" 2 "2 Ausfälle" 3 "3+ Ausfälle" 4 "HH/GU ganz ausgef.", add modify
* numlabel hhgr_diff, add mask("[#] ") force
lab val hhgr_diff_4 hhgr_diff
* lab var hhgr_diff   "Diff. hhgr (t-1) - hhgr (t): vor Ausfall alle Übergänge"

* ==============================================================================

/* Vorbereitung für Analysen mit MZ-Panel 2001-2004
   alt_*     Alter (längsschnittkonsistent)
   altr_*    Altersgruppen
   sex_*     Geschlecht (längsschnittkonsistent)
   famst_*   Familienstand
   pghu_*    Haushaltstyp
   hws_*     Haupt-/Nebenwohnsitz
*/

* Alter zum Panelzeitpunkt ...  
*    alt_* <- Jahr - gebj (Geb.jahr längsschnittkonsistent) | gültige Angaben t
gen alt_1 = 2012 - gebj if r1==1
gen alt_2 = 2013 - gebj if r2==1
gen alt_3 = 2014 - gebj if r3==1
gen alt_4 = 2015 - gebj if r4==1
sum alt_* 
* alt_* kann bei Jahresüberhängen -1 sein
recode alt_* (-1 = 0) (96/99 = 96)
* Kontrolle
* for var alt_* \ var ef44_* : tabstat X Y if Y>=0 & Y<., s(mean min p1 p5 p10 p25 p50 p75 p90 p95 p99 max) col(stat)
lab var alt_1 "Alter 2012 <- 2012-gebj"
lab var alt_2 "Alter 2013 <- 2013-gebj"
lab var alt_3 "Alter 2014 <- 2014-gebj"
lab var alt_4 "Alter 2015 <- 2015-gebj"
lab def alt 0 "<1 Jahr" 96 "96+ Jahre"
for var alt_* : lab val X alt

* ------------------------------------------------------------------------------

* Altersgruppen 
recode alt_1 alt_2 alt_3 alt_4 ///
       (0/4=0)    (5/9=5)    (10/14=10) (15/19=15) (20/24=20) (25/29=25) ///
       (30/34=30) (35/39=35) (40/44=40) (45/49=45) (50/54=50) (55/59=55) ///
       (60/64=60) (65/69=65) (70/74=70) (75/79=75) (80/84=80) (85/89=85) ///
       (90/99=90), gen(altr_1 altr_2 altr_3 altr_4)
lab var altr_1 "Altersgruppen t1" //  <- gebj"
lab var altr_2 "Altersgruppen t2"
lab var altr_3 "Altersgruppen t3"
lab var altr_4 "Altersgruppen t4"
lab def altr   0 "0-4"    5 "5-9"   10 "10-14" 15 "15-19" 20 "20-24" ///
              25 "25-29" 30 "30-34" 35 "35-39" 40 "40-44" 45 "45-49" ///
              50 "50-54" 55 "55-59" 60 "60-64" 65 "65-69" 70 "70-74" ///
              75 "75-79" 80 "80-84" 85 "85-89" 90 "90-99", add modify
numlabel altr, add mask("[#] ") force
for var altr_1 altr_2 altr_3 altr_4 : lab val X altr

* ------------------------------------------------------------------------------

* Geschlecht (längsschnittkonsistent) zum Panelzeitpunkt ...
gen     sex_1 = sex if r1==1
gen     sex_2 = sex if r2==1
gen     sex_3 = sex if r3==1
gen     sex_4 = sex if r4==1
lab var sex_1 "sex 2012 <- sex"
lab var sex_2 "sex 2013 <- sex"
lab var sex_3 "sex 2014 <- sex"
lab var sex_4 "sex 2015 <- sex"
lab val sex_* sex

* ------------------------------------------------------------------------------

* famst	Familienstand
for var ef765_1 ef765_2 ef765_3 ef765_4 \ var r1 r2 r3 r4 \ new famst_1 famst_2 famst_3 famst_4 : recode X (1=1) (2 3 6 7=2) (5=3) (4 8=4) (-8 -7 . = .) if Y==1, gen(Z)
lab var famst_1 "Familienstand <- ef765_1"
lab var famst_2 "Familienstand <- ef765_2"
lab var famst_3 "Familienstand <- ef765_3"
lab var famst_4 "Familienstand <- ef765_4"
lab def famst 1 "ledig" 2 "verheiratet, eLP" 3 "verwitwet, eLP verst." 4 "geschieden, eLP aufgehob."
numlabel famst , add mask("[#] ") force
for var famst_* : lab val X famst

* -----------------------------------------------------------------------------

* pghu Haushaltstyp
for var ef31_1 ef31_2 ef31_3 ef31_4 \ var r1 r2 r3 r4 \ new phgu_1 phgu_2 phgu_3 phgu_4 : recode X (1=0) (2=1) (*=.) if Y==1, gen(Z) 
lab var phgu_1 "Priv.HH, Gem.unterk. <- ef31_1"
lab var phgu_2 "Priv.HH, Gem.unterk. <- ef31_2"
lab var phgu_3 "Priv.HH, Gem.unterk. <- ef31_3"
lab var phgu_4 "Priv.HH, Gem.unterk. <- ef31_4"
lab def phgu 0 "Privathaushalt" 1 "Gemeinschaftsunterkunft"
numlabel phgu , add mask("[#] ") force
for var phgu_* : lab val X phgu

* -----------------------------------------------------------------------------

* hws Haupt-/Nebenwohnsitz
for var ef30_1 ef30_2 ef30_3 ef30_4 \ var r1 r2 r3 r4 \ new hws_1 hws_2 hws_3 hws_4 : recode X (1 2=0) (3=1) (*=.) if Y==1, gen(Z) 
lab var hws_1 "Haupt-/Nebenwohnsitz t1"
lab var hws_2 "Haupt-/Nebenwohnsitz t2"
lab var hws_3 "Haupt-/Nebenwohnsitz t3"
lab var hws_4 "Haupt-/Nebenwohnsitz t4"
lab def hws 0 "Hauptwohnsitz" 1 "Nebenwohnsitz", add modify
numlabel hws, add mask("[#] ") force
for var hws_* : lab val  X hws

* -----------------------------------------------------------------------------

* verlust_* vergleichbar zum MZ-Panel 2001-2004 recodieren, 
*           temporäre Ausfälle mit Wiedereintritt als Fortzug behandeln

* att       [2] Wiedereintritt, temporärer Ausfall
* verlust_2 [9] Nicht zuordenbare Ausfälle
recode verlust_2 verlust_3 verlust_4 (3=4), copyrest

replace verlust_2 = 5 if att==2 & (verlust_2==4 | verlust_2==9) & (ausftyp==27 & ausftyp<=30)
replace verlust_3 = 6 if att==2 & (verlust_3==4 | verlust_3==9) & (ausftyp==4 | ausftyp==8 | ausftyp==26  | ausftyp==38 | ausftyp==39) 
lab def verlust  -2 "ROT letztmals in Stichprobe" ///
                  4 "Fortzug ganzer HH/GU o.A. zum Ausfallgrund" /// ex [3]
                  9 "Nicht zuordenbarer Ausfall ([1], [2], [3])" /// 
                  5 "Ausfall 2013, Teilnahme 2014 oder 2015 -> Fortzug" ///
                  6 "Ausfall 2014, Teilnahme 2015 -> Fortzug", add modify
numlabel verlust, add mask("[#] ") force
for var verlust_2 verlust_3 verlust_4 : lab val X verlust

* =====================================================================

save panel_v2c.dta, replace

log close

exit

/* -----------------------------------------------------------------------------

"Gewinne": Personen ohne gültige Angaben zum Geschlecht t, aber t+1

"Gewinne" werden nicht für Ausfallkorrekturen nach dem Weiterverfolgungskonzept 
benötigt, sondern für Anpassungsgewichte - Hochrechnung auf Population.

Informationen über Gewinne (Geburt, Zuzug) für Personen liegen im zurzeit nicht
nutzbaren Merkmal EF615 "Veränderung der Person (alte Rotationsviertel)" vor.

Angaben zur Geburt können unter Verwendung des Geburtsjahres (EF47) oder des 
Alters (EF44) und des Erhebungszeitpunktes (gemäß Stichprobenplan) nur 
näherungsweise ermittelt werden, da keine Angaben zum Monat der Befragung und 
zum Geburtsmonat vorliegen.

Angaben zum Zuzug enthalten die auf Retrospektivfragen beruhenden nutzbaren 
Merkmale 
EF451 "Selber Wohnsitz (vor einem Jahr) (FB)" und
EF455 "Wohnungswechsel (i. d. letzten 12 Monaten): Staat d. früh. Wohnsitzes".
Damit können Zuzüge aus Deutschland und aus dem Ausland unterschieden werden.
*/

* Übergang 2012->2013
generate gewinn_2 = -9 if r1==0 & r2==1
* Rotationsgruppe 83: 2013 erstmals in der Stichprobe
replace  gewinn_2 = -1 if gewinn_2==-9 & rot==83
* alt_2  Alter 2013
* ef451_2 Selber Wohnsitz (vor einem Jahr) (FB): -5 Entfällt (Person unter 1 Jahr) 
replace  gewinn_2 =  1 if gewinn_2==-9 & r1==0 & r2==1 & alt_2==0 & ef451_2==-5 & rot<83
* ef45_2  Zuzug (i. d. letzten 12 Monaten): 1 Ja
replace  gewinn_2 =  2 if gewinn_2==-9 & r1==0 & r2==1 & alt_2>=1 & alt_2<=95 & ef45_2==1 & rot<83
* ef455_2 Wohnungswechsel (i. d. letzten 12 Monaten): Staat d. früh. Wohnsitzes 
replace  gewinn_2 =  3 if gewinn_2==2 & ef455_2>0 & ef455_2<999
* ef45_2 Zuzug ...: 8 Nein
replace  gewinn_2 =  0 if gewinn_2==-9 & ef45_2==8
replace  gewinn_2 =  9 if gewinn_2==-9
lab var gewinn_2 "Art Gewinne Übergang 2012->2013"
lab def gewinn 0 "Keine Veränderung durch Geburt/Zuzug" ///
               1 "Geburt" ///
               2 "Zuzug aus DE" ///
               3 "Zuzug aus Ausland" ///
               9 "Nicht zuordenbar" ///
              -1 "Rot. erstmals in Stichprobe", add modify
numlabel gewinn, add mask("[#] ") force
lab val gewinn_2 gewinn

* ---------------------------------------------------------------------

* Übergang 2013->2014
generate gewinn_3 = -9 if r2==0 & r3==1
* Rotationsgruppe 84: 2014 erstmals in der Stichprobe
replace  gewinn_3 = -1 if gewinn_3==-9 & rot==84
* alt_3  Alter 2014
* ef451_3 Selber Wohnsitz (vor einem Jahr) (FB): -5 Entfällt (Person unter 1 Jahr) 
replace  gewinn_3 =  1 if gewinn_3==-9 & r2==0 & r3==1 & alt_3==0 & ef451_3==-5 & rot<84
* ef45_3  Zuzug (i. d. letzten 12 Monaten): 1 Ja
replace  gewinn_3 =  2 if gewinn_3==-9 & r2==0 & r3==1 & alt_3>=1 & alt_3<=95 & ef45_3==1 & rot<84
* ef455_3 Wohnungswechsel (i. d. letzten 12 Monaten): Staat d. früh. Wohnsitzes 
replace  gewinn_3 =  3 if gewinn_3==2 & ef455_3>0 & ef455_3<999
* ef45_3 Zuzug ...: 8 Nein
replace  gewinn_3 =  0 if gewinn_3==-9 & ef45_3==8
replace  gewinn_3 =  9 if gewinn_3==-9
lab var gewinn_3 "Art Gewinne Übergang 2013->2014"
lab val gewinn_3 gewinn

* ---------------------------------------------------------------------

* Übergang 2014->2015
generate gewinn_4 = -9 if r3==0 & r4==1
* Rotationsgruppe 91: 2015 erstmals in der Stichprobe
replace  gewinn_4 = -1 if gewinn_4==-9 & rot==91
* alt_4  Alter 2015
* ef451_4 Selber Wohnsitz (vor einem Jahr) (FB): -5 Entfällt (Person unter 1 Jahr) 
replace  gewinn_4 =  1 if gewinn_4==-9 & r3==0 & r4==1 & alt_4==0 & ef451_4==-5 & rot<91
* ef45_4  Zuzug (i. d. letzten 12 Monaten): 1 Ja
replace  gewinn_4 =  2 if gewinn_4==-9 & r3==0 & r4==1 & alt_4>=1 & alt_4<=95 & ef45_4==1 & rot<91
* ef455_4 Wohnungswechsel (i. d. letzten 12 Monaten): Staat d. früh. Wohnsitzes 
replace  gewinn_4 =  3 if gewinn_4==2 & ef455_4>0 & ef455_4<999
* ef45_4 Zuzug ...: 8 Nein
replace  gewinn_4 =  0 if gewinn_4==-9 & ef45_4==8
replace  gewinn_4 =  9 if gewinn_4==-9
lab var gewinn_4 "Art Gewinne Übergang 2014->2015"
lab val gewinn_4 gewinn


