* prog_3a.do 

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns

* Schätzung und Klassifikation der Ausfallgründe für den Übergang 2012 -> 2013
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
set seed 54721

cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using prog_3a.log, text

* Auswahl
use idpers idpsu idhh rot att gebj ausftyp ///
    r1          r2          r3         r4  /// Teilnahme (gültige Angaben) 2012, 2013, 2014, 2015
    verlust_2   verlust_3   verlust_4      /// Art Verluste Übergang 2012->2013, 2013->2014, 2014->2015
    altr_1      altr_2      altr_3         /// Altersgruppe
    alt_1       alt_2       alt_3          /// Alter in Jahren
    sex_1       sex_2       sex_3          /// Geschlecht - längsschnittkonsistent
    famst_1     famst_2     famst_3        /// Familienstand
    phgu_1      phgu_2      phgu_3         /// Haushaltstyp
    hws_1       hws_2       hws_3          /// Bevölkerung am Haupt-/Nebenwohnsitz
    hhgr_diff_2 hhgr_diff_3 hhgr_diff_4    /// Differenz der Haushaltsgrößen zum Zeitpunkt t-1 - t
 if rot==82 & att==1                       /// Rotationsgruppe 82 (2012-2015 in Stichprobe), mit Teilnahme verschachtelte Ausfälle (ohne temporäre Ausfälle und Zugänge)
 using panel_v2c.dta

keep if r1==1 & r2==0 & att==1 & verlust_2==9 // * ohne Ausfälle ganzer HH/GU o.A. zum Ausfallgrund 
keep idpers idpsu verlust_2 r1 r2 att altr_1 alt_1 sex_1 

* Variablen vergleichbar mit MZ-Panel 2001-2004 (dat=0) erstellen
/*
MZP 01-04 (Analysestichprobe): 
"Durchschnitt" der 3 Übergänge mit den Angaben zu Ausfallgründen: 
[1] Sterbefall, [2] Fortzug, [3] Fortzug/Sterbefall ohne [4] Haushalt/
    Gem.unterk. vollständig ausgefallen, keine Zuzüge, keine Angaben zum 
    Ausfallgrund.
Die Angaben zum Ausfall in der Typisierung verlustp „Kennzeichnung der 
   Art des Verlustes auf Personenebene” wurden für die Auswahl perkl>=1 & 
   perkl<=15 nachträglich analog zur Abgrenzung im Programm prog_2c.do 
   recodiert.
Die erklärenden Variablen enthalten den Status vor dem typisierten 
   Ausfallgrund (t-1).
Auswahl: Weiterverfolgungskonzept, plausibel zusammengeführte Daten 
   (perkl>=1 & perkl<=3).
*/
* MZP 12-15: Übergang 12->13
gen verlust = . // verlust_2=9 Nicht zuordenbarer Ausfall [1] Sterbefall, [2] Fortzug, [3] Fortzug oder Sterbefall
gen altr    = altr_1
gen alt     = alt_1
gen altq    = alt^2
gen sex     = sex_1

append using <mzp01_modelldaten.dta>, gen(dat) // nicht dokumentiert 

recode dat (0=1) (1=0)
lab var dat "Datenquelle"
lab def dat 0 "MZP 01" 1 "MZP 12->13"
numlabel dat, add mask("[#] ") force
lab val dat dat

* tabstat verlust altr alt altq , by(dat) s(count sum mean)

* Modell M1: Altersgruppe, (Alter, Alter²)*Geschlecht
mlogit verlust o0.altr ib90.altr (c.alt c.altq)##ib1.sex if ((dat==0 & verlust>=1 & verlust<=3) | (dat==1 & verlust==.)), baseoutcome(2) vce(cluster idpsu)
estimates store m1
estat ic

* predicted probabilities for outomes [1] Sterbefall [2] Fortzug [3] Fortzug oder Sterbefall
predict double p1 , pr outcome(1)
predict double p2 , pr outcome(2)
predict double p3 , pr outcome(3)
lab var p1 "P^ verlust==1" // Sterbefall
lab var p2 "P^ verlust==2" // Fortzug
lab var p3 "P^ verlust==3" // Fortzug oder Sterbefall

* tabstat p1 p2 p3, by(dat) s(count sum mean) longstub m

* linear prediction for outcomes ...
predict xb1 , outcome(1) index
predict xb2 , outcome(2) index
predict xb3 , outcome(3) index

* standard error of the prediction for outcome ...
predict double se1 , outcome(1) stdp
predict double se2 , outcome(2) stdp
predict double se3 , outcome(3) stdp

* xbdiff*: difference in two linear predictions
gen double     xbdiff12 = xb1-xb2 
gen double     xbdiff13 = xb1-xb3 
gen double     xbdiff23 = xb2-xb3 

* sediff*: standard error of the difference in two linear predictions
predict double sediff12 , outcome(1,2) stddp
predict double sediff13 , outcome(1,3) stddp
predict double sediff23 , outcome(2,3) stddp

* zdiff*: z statistic
gen double     zdiff12 = xbdiff12/sediff12 if xbdiff12!=.
gen double     zdiff13 = xbdiff13/sediff13 if xbdiff13!=.
gen double     zdiff23 = xbdiff23/sediff23 if xbdiff23!=.

* zxb*: z statistic of linear predictions for outcomes
gen double     zxb1 = xb1/se1 if xb1!=.
gen double     zxb2 = xb2/se2 if xb2!=.
gen double     zxb3 = xb3/se3 if xb3!=.

* Klassifikation der Modellergebnisse
gen byte verltypm1 = 3
replace  verltypm1 = 1 if p1>(p2+p3)    & zdiff12 >  1.96
replace  verltypm1 = 2 if p2>p1 & p2>p3 & zdiff12 < -1.96
lab def verlust 1 "Sterbefall" 2 "Fortzug" 3 "Fortzug/Sterbefall", add modify
numlabel verlust, add mask("[#] ") force
lab val verlust verlust
lab val verltypm1 verlust

tab verlust verltypm1 if dat==0, row col // siehe Tabelle 6
/*
                      |            verltypm1
              verlust | [1] Sterb  [2] Fortz  [3] Fortz |     Total
----------------------+---------------------------------+----------
       [1] Sterbefall |      1118         29        766 |      1913 
                      |     58,44       1,52      40,04 |    100,00 
                      |     61,84       0,72      11,18 |     15,07 
----------------------+---------------------------------+----------
          [2] Fortzug |       101       2567       1756 |      4424 
                      |      2,28      58,02      39,69 |    100,00 
                      |      5,59      63,65      25,63 |     34,86 
----------------------+---------------------------------+----------
[3] Fortzug/Sterbefal |       589       1437       4329 |      6355 
                      |      9,27      22,61      68,12 |    100,00 
                      |     32,58      35,63      63,19 |     50,07 
----------------------+---------------------------------+----------
                Total |      1808       4033       6851 |     12692 
                      |     14,25      31,78      53,98 |    100,00 
                      |    100,00     100,00     100,00 |    100,00 
*/

tab verltypm1 dat, col
/*
                      |      Datenquelle
            verltypm1 | [0] MZP 0  [1] MZP 1 |     Total
----------------------+----------------------+----------
       [1] Sterbefall |      1808        563 |      2371 
                      |     14,25      17,14 |     14,84 
----------------------+----------------------+----------
          [2] Fortzug |      4033       1453 |      5486 
                      |     31,78      44,23 |     34,34 
----------------------+----------------------+----------
[3] Fortzug/Sterbefal |      6851       1269 |      8120 
                      |     53,98      38,63 |     50,82 
----------------------+----------------------+----------
                Total |     12692       3285 |     15977 
                      |    100,00     100,00 |    100,00 
*/

rename verltypm1 verltypr_2
keep if dat==1
keep idpers verltypr_2
sort idpers

merge 1:1 idpers using panel_v2c.dta
drop _merge

* Beachte
* verltypr_2 ist nur definiert für rot==82 & att==1
replace verltypr_2 =  0 if  verltypr_2==. & r1==1 & r2==1  & rot==82
replace verltypr_2 =  4 if  verltypr_2==. & r1==1 & r2==0 & verlust_2==4 & rot==82 & att==1 // Fortzug ganzer HH/GU o.A. zum Ausfallgrund
lab var verltypr_2 "Klassif. geschätzter Ausfalltypen 2012/13 <- verltypm1 rot=82 att=0,1 Modell 1"
lab def verltypr  0 "kein Ausfall" ///
                  1 "Sterbefall imputiert <- verltypm1" ///
                  2 "Fortzug imputiert <- verltypm1"  /// 
                  3 "Fortzug/Sterbefall imputiert <- verltypm1" ///
				  4 "Fortzug ganzer HH/GU o.A. zum Ausfallgrund", add modify
numlabel verltypr, add mask("[#] ") force
lab val verltypr_2 verltypr

* Teilnahme/Ausfall Übergang 12->13, rot=82 & att=0,1
* tab verltypr_2 verlust_2 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1, m col
tab verltypr_2 r2 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1, m col // siehe Tabelle 7
/*
 Klassif. geschätzter |   Response gültige
 Ausfalltypen 2012/13 |     Angaben - t2
         <- verltypm1 |  [0] nein     [1] ja |     Total
----------------------+----------------------+----------
     [0] kein Ausfall |         0     107948 |    107948 
                      |      0,00     100,00 |     89,25 
----------------------+----------------------+----------
[1] Sterbefall imputi |       563          0 |       563 
                      |      4,33       0,00 |      0,47 
----------------------+----------------------+----------
[2] Fortzug imputiert |      1453          0 |      1453 
                      |     11,18       0,00 |      1,20 
----------------------+----------------------+----------
[3] Fortzug/Sterbefal |      1269          0 |      1269 
                      |      9,76       0,00 |      1,05 
----------------------+----------------------+----------
[4] Fortzug ganzer HH |      9712          0 |      9712 
                      |     74,72       0,00 |      8,03 
----------------------+----------------------+----------
                Total |     12997     107948 |    120945 
                      |    100,00     100,00 |    100,00 
*/

save panel_v3a.dta, replace

log close


