* test_prog_3b.do 

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns

* Schätzung und Klassifikation der Ausfallgründe für den Übergang 2013 -> 2014
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
set seed 54721

cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using prog_3b.log, text

* Auswahl
use idpers idpsu idhh rot att gebj ausftyp ///
    r1          r2          r3         r4  /// Teilnahme (gültige Angaben) 2012, 2013, 2014, 2015
    verlust_2   verlust_3   verlust_4      /// Art Verluste Übergang 2012->2013, 2013->2014, 2014->2015
    altr_1      altr_2      altr_3         /// Altersgruppe
    alt_1       alt_2       alt_3          /// Alter in Jahren
    sex_1       sex_2       sex_3          /// Geschlecht - längsschnittkonsistent
    famst_1     famst_2     famst_3        /// Familienstand
    phgu_1      phgu_2      phgu_3         /// Haushaltstyp
    hws_1       hws_2       hws_3          /// Bevölkerung am Haupt-/Nebenwohnsitz
    hhgr_diff_2 hhgr_diff_3 hhgr_diff_4    /// Differenz der Haushaltsgrößen zum Zeitpunkt t-1 - t
  if rot==82 & att==1                      /// Rotationsgruppe 82 (2012-2015 in Stichprobe), mit Teilnahme verschachtelte Ausfälle (ohne temporäre Ausfälle und Zugänge)
 using panel_v3a.dta, replace

keep if r1==1 & r2==1 & r3==0 & att==1 & verlust_3==9 // * ohne Ausfälle ganzer HH/GU o.A. zum Ausfallgrund 
keep idpers idpsu verlust_3 r1 r2 r3 att altr_2 alt_2 sex_2 

* Variablen vergleichbar mit MZ-Panel 2001-2004 (dat=0) erstellen
/*
MZP 01-04 (Analysestichprobe): 
"Durchschnitt" der 3 Übergänge mit den Angaben zu Ausfallgründen: 
[1] Sterbefall, [2] Fortzug, [3] Fortzug/Sterbefall ohne [4] Haushalt/
    Gem.unterk. vollständig ausgefallen, keine Zuzüge, keine Angaben zum 
    Ausfallgrund.
Die Angaben zum Ausfall in der Typisierung verlustp „Kennzeichnung der 
   Art des Verlustes auf Personenebene” wurden für die Auswahl perkl>=1 & 
   perkl<=15 nachträglich analog zur Abgrenzung im Programm prog_2c.do 
   recodiert.
Die erklärenden Variablen enthalten den Status vor dem typisierten 
   Ausfallgrund (t-1).
Auswahl: Weiterverfolgungskonzept, plausibel zusammengeführte Daten 
   (perkl>=1 & perkl<=3).
*/
* MZP 12-15: Übergang 13->14
gen verlust = . // verlust_3=9 Nicht zuordenbarer Ausfall [1] Sterbefall, [2] Fortzug, [3] Fortzug oder Sterbefall
gen altr    = altr_2
gen alt     = alt_2
gen altq    = alt^2
gen sex     = sex_2

append using <mzp01_modelldaten.dta>, gen(dat) // nicht dokumentiert

recode dat (0=1) (1=0)
lab var dat "Datenquelle"
lab def dat 0 "MZP 01" 1 "MZP 13->14"
numlabel dat, add mask("[#] ") force
lab val dat dat

* tabstat verlust altr alt altq , by(dat) s(count sum mean)

* Modell M1: Altersgruppe, (Alter, Alter²)*Geschlecht
mlogit verlust o0.altr ib90.altr (c.alt c.altq)##ib1.sex if ((dat==0 & verlust>=1 & verlust<=3) | (dat==1 & verlust==.)), baseoutcome(2) vce(cluster idpsu)
estimates store m1
estat ic

* predicted probabilities for outomes [1] Sterbefall [2] Fortzug [3] Fortzug oder Sterbefall
predict double p1 , pr outcome(1)
predict double p2 , pr outcome(2)
predict double p3 , pr outcome(3)
lab var p1 "P^ verlust==1" // Sterbefall
lab var p2 "P^ verlust==2" // Fortzug
lab var p3 "P^ verlust==3" // Fortzug oder Sterbefall

* tabstat p1 p2 p3, by(dat) s(count sum mean) longstub m

* linear prediction for outcomes ...
predict xb1 , outcome(1) index
predict xb2 , outcome(2) index
predict xb3 , outcome(3) index

* standard error of the prediction for outcome ...
predict double se1 , outcome(1) stdp
predict double se2 , outcome(2) stdp
predict double se3 , outcome(3) stdp

* xbdiff*: difference in two linear predictions
gen double     xbdiff12 = xb1-xb2 
gen double     xbdiff13 = xb1-xb3 
gen double     xbdiff23 = xb2-xb3 

* sediff*: standard error of the difference in two linear predictions
predict double sediff12 , outcome(1,2) stddp
predict double sediff13 , outcome(1,3) stddp
predict double sediff23 , outcome(2,3) stddp

* zdiff*: z statistic
gen double     zdiff12 = xbdiff12/sediff12 if xbdiff12!=.
gen double     zdiff13 = xbdiff13/sediff13 if xbdiff13!=.
gen double     zdiff23 = xbdiff23/sediff23 if xbdiff23!=.

* zxb*: z statistic of linear predictions for outcomes
gen double     zxb1 = xb1/se1 if xb1!=.
gen double     zxb2 = xb2/se2 if xb2!=.
gen double     zxb3 = xb3/se3 if xb3!=.

* Klassifikation der Modellergebnisse
gen byte verltypm1 = 3
replace  verltypm1 = 1 if p1>(p2+p3)    & zdiff12 >  1.96
replace  verltypm1 = 2 if p2>p1 & p2>p3 & zdiff12 < -1.96
lab def verlust 1 "Sterbefall" 2 "Fortzug" 3 "Fortzug/Sterbefall", add modify
numlabel verlust, add mask("[#] ") force
lab val verlust verlust
lab val verltypm1 verlust

tab verlust verltypm1 if dat==0, row col

tab verltypm1 dat, col
/*
                      |      Datenquelle
            verltypm1 | [0] MZP 0  [1] MZP 1 |     Total
----------------------+----------------------+----------
       [1] Sterbefall |      1808        490 |      2298 
                      |     14,25      18,51 |     14,98 
----------------------+----------------------+----------
          [2] Fortzug |      4033       1186 |      5219 
                      |     31,78      44,81 |     34,02 
----------------------+----------------------+----------
[3] Fortzug/Sterbefal |      6851        971 |      7822 
                      |     53,98      36,68 |     50,99 
----------------------+----------------------+----------
                Total |     12692       2647 |     15339 
                      |    100,00     100,00 |    100,00 
*/

rename verltypm1 verltypr_3
keep if dat==1
keep idpers verltypr_3
sort idpers

merge 1:1 idpers using panel_v3a.dta
drop _merge

* Beachte
* verltypr_43ist nur definiert für rot==82 & att==1
replace verltypr_3 =  0 if  verltypr_3==. & r1==1 & r2==1 & r3==1 & rot==82  // kein Ausfall 
replace verltypr_3 =  4 if  verltypr_3==. & r1==1 & r2==1 & r3==0 & verlust_3==4 & rot==82 & att==1 // Fortzug ganzer HH/GU o.A. zum Ausfallgrund
lab var verltypr_3 "Klassif. geschätzter Ausfalltypen 2013/14 <- verltypm1 rot=82 att=0,1 Modell 1"
/* lab def verltypr  0 "kein Ausfall" ///
                  1 "Sterbefall imputiert <- verltypm1" ///
                  2 "Fortzug imputiert <- verltypm1"  /// 
                  3 "Fortzug/Sterbefall imputiert <- verltypm1" ///
				  4 "Fortzug ganzer HH/GU o.A. zum Ausfallgrund", add modify
numlabel verltypr, add mask("[#] ") force */
lab val verltypr_3 verltypr

* Teilnahme/Ausfall Übergang 13->14, rot=82 & att=0,1
tab verltypr_3 verlust_3 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3>=0 & r3<=1, m col
/*
                      |      Art Verluste Übergang
                      |            2013->2014
           verltypr_3 | [4] Fortz  [9] Nicht          . |     Total
----------------------+---------------------------------+----------
     [0] kein Ausfall |         0          0      97964 |     97964 
                      |      0,00       0,00     100,00 |     90,75 
----------------------+---------------------------------+----------
[1] Sterbefall imputi |         0        490          0 |       490 
                      |      0,00      18,51       0,00 |      0,45 
----------------------+---------------------------------+----------
[2] Fortzug imputiert |         0       1186          0 |      1186 
                      |      0,00      44,81       0,00 |      1,10 
----------------------+---------------------------------+----------
[3] Fortzug/Sterbefal |         0        971          0 |       971 
                      |      0,00      36,68       0,00 |      0,90 
----------------------+---------------------------------+----------
[4] Fortzug ganzer HH |      7337          0          0 |      7337 
                      |    100,00       0,00       0,00 |      6,80 
----------------------+---------------------------------+----------
                Total |      7337       2647      97964 |    107948 
                      |    100,00     100,00     100,00 |    100,00 
*/

tab verltypr_3 r3 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3>=0 & r3<=1, m col // siehe Tabelle 7
/*
                      |   Response gültige
                      |     Angaben - t3
           verltypr_3 |  [0] nein     [1] ja |     Total
----------------------+----------------------+----------
     [0] kein Ausfall |         0      97964 |     97964 
                      |      0,00     100,00 |     90,75 
----------------------+----------------------+----------
[1] Sterbefall imputi |       490          0 |       490 
                      |      4,91       0,00 |      0,45 
----------------------+----------------------+----------
[2] Fortzug imputiert |      1186          0 |      1186 
                      |     11,88       0,00 |      1,10 
----------------------+----------------------+----------
[3] Fortzug/Sterbefal |       971          0 |       971 
                      |      9,73       0,00 |      0,90 
----------------------+----------------------+----------
[4] Fortzug ganzer HH |      7337          0 |      7337 
                      |     73,49       0,00 |      6,80 
----------------------+----------------------+----------
                Total |      9984      97964 |    107948 
                      |    100,00     100,00 |    100,00 
*/

save panel_v3b.dta, replace

log close


