* prog_4a.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns

* Vorbereitung der Modelle zur Ausfallkorrektur/-gewichtung
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
set seed 54721

cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using test_prog_4a.log, text replace

use panel_v3c.dta, replace

* Auswahl: 
* Rotationsgruppe 82 (2012-2015 in Stichprobe), Weiterverfolgungskonzept
keep if rot==82 & att>=0 & att<=1

* =========== Variablenkonstruktion für Ausfallanalysen ===========

* west_ost <- Bundesland - Designvariable
recode ef1 (1/10=1) (11/16=2), gen(west_ost)
lab var west_ost "West / Ost <- Bundesland (ef1)"
lab def west_ost 1 "West"  2 "Ost (incl. West-Berlin)"
numlabel west_ost , add mask("[#] ") force
lab val west_ost west_ost
tab west_ost, m

* ------------------------------------------------------------------------------

* altr_ Altersgruppen (Untergr.) <- gebj
for var altr_1 altr_2 altr_3 \ var r1 r2 r3 : tab X if Y==1, m

* ------------------------------------------------------------------------------

* famst_ Familienstand <- ef765
*   alte Version für Vergleich mit MZP 2001-2004 umbenennen
rename (famst_1 famst_2 famst_3 famst_4) (famst_1_alt famst_2_alt famst_3_alt famst_4_alt)
recode ef765_1 ef765_2 ef765_3 ef765_4 (-8 -7=.) (1 3 7 = 1) (2 6 = 2) ///
          (4 8 = 3) (5 = 4), gen(famst_1 famst_2 famst_3 famst_4)
lab def famst 1 "Ledig, verh getr.leb., eLP getr.leb." ///
              2 "Verheiratet zus.leb., eLP zus.leb." ///
              3 "Geschieden, eLP aufgehob." ///
              4 "Verwitwet, eLP verst.", add modify
numlabel famst, add mask("[#] ") force 
lab var famst_1 "Familienstand <- ef765_1"
lab var famst_2 "Familienstand <- ef765_2"
lab var famst_3 "Familienstand <- ef765_3"
lab var famst_4 "Familienstand <- ef765_4"
for var famst_1 famst_2 famst_3 famst_4 : lab val X famst
for var famst_1 famst_2 famst_3 \ var r1 r2 r3 : tab X if Y==1, m

* ------------------------------------------------------------------------------

* hws_ Wohnrechtstatus ([0] Hauptwohnsitz; [1] Nebenwohnsitz) 
for var hws_1 hws_2 hws_3 \ var r1 r2 r3 : tab X if Y==1, m

* ------------------------------------------------------------------------------

* hhtyp_* Haushaltstyp ([0] Privathaushalt; [1] Gemeinschaftsunterkunft) 
rename phgu_* hhtyp_*
lab var hhtyp_1 "Haushaltstyp - t1"
lab var hhtyp_2 "Haushaltstyp - t2"
lab var hhtyp_3 "Haushaltstyp - t3"
lab var hhtyp_4 "Haushaltstyp - t4"
for var hhtyp_1 hhtyp_2 hhtyp_3  \ var r1 r2 r3 : tab X if Y==1, m

* ------------------------------------------------------------------------------

* nat_ Staatsangehörigkeit ([1] Deutsch; [2] Ausländer) 
recode ef371_1 ef371_2 ef371_3 ef371_4 (1=1) (2 3 = 2) (. -7 -8=.), gen(nat_1 nat_2 nat_3 nat_4)
lab var nat_1 "Staatsangehörigkeit - t1"
lab var nat_2 "Staatsangehörigkeit - t2"
lab var nat_3 "Staatsangehörigkeit - t3"
lab var nat_4 "Staatsangehörigkeit - t4"
lab def nat  1 "DE" 2 "AUSL" , add modify
numlabel nat, add mask("[#] ") force
for var nat_1 nat_2 nat_3 nat_4 : lab val X nat
for var nat_1 nat_2 nat_3 \ var r1 r2 r3 : tab X if Y==1 ,  m 

* ------------------------------------------------------------------------------

* sex_ Geschlecht (längsschnittkonsistent recodiert: [1] männlich; [2] weiblich) 

* ------------------------------------------------------------------------------

* casr_ CASMIN-Bildungsklassifikation  (GESIS  2016, Version „casa” recodiert 
*       und ergänzt um Kategorien zum Schul- und Hochschulbesuch
* MZ 2012
recode ef310_1  (-9=-9) (-7 -8=.) (-3 -5 9=0 "[0] entf./o.A.") (6=1 "[1] kein AB") ///  
                (1=2 "[2] HS/VS") (2 3 7=3 "[3] RS/POS") (4 5=4 "[4] FHR/ABI"), ///
       gen(schul)
replace schul=1 if (ef309_1==8)
recode ef312_1  (-9=-9) (-7 -8=.) (-3 -5 99=0 "[0] entf./o.A.") (1/10=2 "[2] Ausb.") ///
               (11/13=3 "[3] FH/Berufsakad.") (14/15=4 "[4] Uni"), gen(ber)
replace ber=1 if (ef311_1==8)
gen cas_1=99 if schul!=. & ber!=.
replace cas_1=99 if schul==0 | ber==0
replace cas_1=0 if (schul>=0 & schul<=1 & ber==1) | (schul==1 & ber==0)
replace cas_1=1 if schul==2 & ber>=0 & ber<=1
replace cas_1=2 if schul>=0 & schul<=2 & ber==2
replace cas_1=3 if schul==3 & ber>=0 & ber<=1
replace cas_1=4 if schul==3 & ber==2
replace cas_1=5 if schul==4 & ber>=0 & ber<=1
replace cas_1=6 if schul==4 & ber==2
replace cas_1=7 if schul>=0 & schul<=4 & ber==3
replace cas_1=8 if schul>=0 & schul<=4 & ber==4 
replace cas_1=-9 if ef312_1==-9 | ef310_1==-9
lab variable cas_1 "CASMIN - t1"
label define cas 0 "[0] 1a (kein Ab.)"  1 "[1] 1b (HSO)" 2 " [2] 1c (HSM)" ///
                 3 "[3] 2b (MRO)" 4 "[4] 2a (MRM)" 5 "[5] 2c_gen (ABIO)" ///
                 6 "[6] 2c_voc (ABIM)" 7 "[7] 3a (FH)" 8 "[8] 3b (UNI)" ///
                99 "[99] entf./o.A."
label values cas_1 cas
gen casa_1=cas_1 if schul!=. & ber!=.
drop cas_1
replace casa_1=9 if ef287_1>=1 & ef287_1<=2
label variable casa_1 "CASMIN - in Ausb. separat - t1"
label define casa 0 "[0] 1a (kein Ab.)" 1 "[1] 1b (HSO)" 2 "[2] 1c (HSM)"  ///
                  3 "[3] 2b (RSO)" 4 "[4] 2a (RSM)" 5 "[5] 2c_gen (ABIO)" ///
                  6 "[6] 2c_voc (ABIM)" 7 "[7] 3a (FH)" 8 "[8] 3b (UNI)" ///
                  9 "[9] in Ausbildung" 99 "[99] entf./o.A."
label values casa_1 casa
drop schul ber
replace casa_1 = 90 if casa_1== 9
replace casa_1 =  9 if casa_1==90 & ef290_1==1  // [1] Klassenstufe 1 bis 4
replace casa_1 = 10 if casa_1==90 & ef290_1==2  // [2] Klassenstufe 5 bis 9/10
replace casa_1 = 11 if casa_1==90 & ef290_1==3  // [3] Gymnasiale Oberstufe
replace casa_1 = 12 if casa_1==90 & ef289_1==12 // [12] Berufl. Schule & MR
replace casa_1 = 13 if casa_1==90 & ef289_1>=13 & ef289_1<=15 // [13] & ABI 
replace casa_1 = 14 if casa_1==90 & ef289_1>=16 & ef289_1<=19 // [16] BFS
replace casa_1 = 15 if casa_1==90 & ef289_1>=20 & ef289_1<=24 // [20] SdG FS BA 
replace casa_1 = 16 if casa_1==90 & ef289_1>=25 & ef289_1<=28 // [25] VFH FH UNI
replace casa_1 =  0 if casa_1==99 // dominant: ef309: [-3] Entf, [9] KA
replace casa_1 =  0 if casa_1==90 & ef310_1>=-5 & ef310_1<=-3
replace casa_1 =  1 if casa_1==90 & ef310_1==1 & (ef312_1==-5 | ef312_1==1)
replace casa_1 =  2 if casa_1==90 & ef310_1==1 & (ef312_1==3  | ef312_1==4)
replace casa_1 =  3 if casa_1==90 & ef310_1==3 &  ef312_1==-5
replace casa_1 =  4 if casa_1==90 & ef310_1==3 & (ef312_1==3  | ef312_1==4)
replace casa_1 =  5 if casa_1==90 & ef310_1>=4 & ef310_1<=5 & ef312_1==-5
replace casa_1 =  6 if casa_1==90 & ef310_1>=4 & ef310_1<=5 & ef312_1>=3 & ef312_1<=4
replace casa_1 =  6 if casa_1==90 & ef310_1>=4 & ef310_1<=5 & ef312_1==11
replace casa_1 =  8 if casa_1==90 & ef310_1>=4 & ef310_1<=5 & ef312_1==14
replace casa_1 =  0 if casa_1==90 & ef310_1==9 & ef312_1==-5
lab def casa_1 0 "1a (kein Ab.), kA" 1 "1b (HSO)" 2 "1c (HSM)"  ///
               3 "2b (RSO)" 4 "2a (RSM)" 5 "2c_gen (ABIO)" 6 "2c_voc (ABIM)" ///
               7 "3a (FH)" 8 "3b (UNI)" 9 "Klasse 1-4" 10 "Klasse 5-9/10" ///
              11 "GY-Oberst." 12 "Berufl. Schule, Ziel MR" ///
              13 "Ber. Sch., Ziel ABI" 14 "BVJ, BGJ, Berufssch. BFS" ///
              15 "Schule Gesundh.wesen" 16 "FH, UNI, Prom.", add modify
numlabel casa_1, add mask("[#] ") force
lab val casa_1 casa_1			 
recode casa_1 (0=0)       /// Kein Abschluss, keine Angabe
            (1 3 = 1)   /// HS, RS ohne Berufsausb.
            (2 4 = 2)   /// RS, RS mit Berufsausb.
            (5/8 = 3)   /// Abi mit Berufsausb., FH, UNI
            (9 10 = 4)  /// Schulbes. Klasse 1-9/10
            (11/16 = 5) /// Schul-/Hochschulbes. GYO-Prom
 , gen(casr_1) // ex (casar_1)
drop casa_1 
lab var casr_1 "Casmin & Schulbes. recodiert - t1" // casar_1
recode casr_1 (-9=9)
lab def casr 0 "Kein Abschluss, keine Angabe" /// casar
           1 "HS, RS ohne Berufsausb." ///
           2 "HS, RS mit Berufsausb." ///
           3 "Abi, FH, UNI" ///
           4 "Schulbes. Klasse 1-9/10" ///
           5 "Schul-/Hochschulbes. GYO-Prom", add modify		   
numlabel casr, add mask("[#] ") force // casar
lab val casr_1 casr // casar_1 casar

* mz 2013
recode ef310_2  (-7 -8=.) /// Entfällt, für Querschnittsausw. nicht relevant
                (-3 -5 9=0 "[0] entf./o.A. (incl. Besuch allg.bild. Schule)") ///   EF* -> ef*
                (6=1       "[1] kein AB") ///  
                (1=2       "[2] HS/VS")  ///
                (2 3 7=3   "[3] RS/POS") ///
                (4 5=4     "[4] FHR/ABI") , generate(schul)
replace schul=1 if (ef309_2==8)
recode ef312_2 (-7 -8=.) /// Entfällt, für Querschnittsausw. nicht relevant
               (-3 -5 99=0 "[0] entf./o.A.") ///
               (1/10=2     "[2] Ausb.") ///
               (11/13=3    "[3] FH/Berufsakad.") /// incl. Verw.-FH, Duale HS
               (14/15=4    "[4] Uni") ///
               (16=2)     /// mz 2014: 16 Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig (z.B. Physiotherapie, Gesundeits- und Krankenpflege, MTA, Altenpflege)
               (17=2), generate(ber) // mz 2014: 17 Ausbildungsstätten/Schulen für Erzieher
			   
replace ber=1 if (ef311_2==8)
generate cas=99 if schul!=. & ber!=.
replace cas=99 if (schul==0 | ber==0)
replace cas=-9 if ef312_2==-9 & ber==-9
replace cas=0  if (((schul==0 | schul==1) & ber==1)  | (schul==1 & ber==0))
replace cas=1  if (schul==2 & (ber==0 | ber==1))
replace cas=2  if ((schul==0 | schul==1 | schul==2) & ber==2)
replace cas=3  if (schul==3 & (ber==0 | ber==1))
replace cas=4  if (schul==3 & ber==2)
replace cas=5  if (schul==4 & (ber==0 | ber==1))
replace cas=6  if (schul==4 & ber==2)
replace cas=7  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==3)
replace cas=8  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==4)
generate casa=cas if schul!=. & ber!=.
drop cas
replace casa=9 if (ef287_2>=1 & ef287_2<=2)
replace casa = 90 if casa== 9 // [9] in Ausbildung | if (ef287>=1 & ef287<=2)
replace casa =  9 if casa==90 & ef290_2==1  // [1] Klassenstufe 1 bis 4
replace casa = 10 if casa==90 & ef290_2==2  // [2] Klassenstufe 5 bis 9/10
replace casa = 11 if casa==90 & ef290_2==3  // [3] Gymnasiale Oberstufe
replace casa = 12 if casa==90 & ef289_2==12 // [12] Berufliche Schule, die zur mittleren Reife führt (z.B. Berufsfachschule)
replace casa = 13 if casa==90 & ef289_2>=13 & ef289_2<=15 // [13] Berufliche Schule, die zur Hochschul-/Fachhochschulreife führt: Fachoberschule, Berufsfachschule, Berufsoberschule, technische Oberschule
replace casa = 14 if casa==90 & ef289_2>=16 & ef289_2<=19 // [16] Berufsvorbereitungsjahr, [17] Berufsgrundbildungsjahr, [18] Berufsschule, [19] Berufsfachschule, die einen Berufsabschluss vermittelt
replace casa = 15 if casa==90 & ef289_2>=20 & ef289_2<=24 // [20] Schulen für Gesundheits-­ und Sozialberufe: einjährig [21] zwei-/dreijährig [22] Fachschule [23] Fachakademie (BY) [24] Berufsakademie
replace casa = 16 if casa==90 & ef289_2>=25 & ef289_2<=28 // [25] Verwaltungsfachhochschule [26] Fachhochschule [27] Universität [28] Promotionsstudium
replace casa =  0 if casa==99 // dominant: ef309_2: [-3] Entfällt (Person unter 15 Jahren), [9] Keine Angabe
replace casa =  0 if casa==90 & ef310_2>=-5 & ef310_2<=-3
replace casa =  1 if casa==90 & ef310_2==1 & (ef312_2==-5 | ef312_2==1)
replace casa =  2 if casa==90 & ef310_2==1 & (ef312_2==3  | ef312_2==4)
replace casa =  3 if casa==90 & ef310_2==3 &  ef312_2==-5
replace casa =  4 if casa==90 & ef310_2==3 & (ef312_2==3  | ef312_2==4)
replace casa =  5 if casa==90 & ef310_2>=4 & ef310_2<=5 & ef312_2==-5
replace casa =  6 if casa==90 & ef310_2>=4 & ef310_2<=5 & ef312_2>=3 & ef312_2<=4
replace casa =  6 if casa==90 & ef310_2>=4 & ef310_2<=5 & ef312_2==11
replace casa =  8 if casa==90 & ef310_2>=4 & ef310_2<=5 & ef312_2==14
replace casa =  0 if casa==90 & ef310_2==9 & ef312_2==-5
replace casa = 0 if casa==90 & ef310_2==6 & ef312_2==-5
recode casa (0=0)       /// Kein Abschluss, keine Angabe
            (1 3 = 1)   /// HS, RS ohne Berufsausb.
            (2 4 = 2)   /// RS, RS mit Berufsausb.
            (5/8 = 3)   /// Abi, FH, UNI
            (9 10 = 4)  /// Schulbes. Klasse 1-9/10
            (11/16 = 5) /// Schul-/Hochschulbes. GYO-Prom
           , gen(casr_2) // ex (casar_2) 
drop casa 
recode casr_2 (-9=9)
replace casr_2 = 5 if casr_2==90 & ef289_2==29 // Schulbesuch: 29 Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig
replace casr_2 = 5 if casr_2==90 & (ef289_2==99 | ef312_2==99) // keine Angaben zum Berufl. Abschl. | Schulbesuch
lab val casr_2 casr // casar_2 casar
lab var casr_2 "Casmin & Schulbes. recodiert - t2" // casar_2

drop schul ber
recode ef310_3 (-7 -8=.) /// Entfällt, für Querschnittsausw. nicht relevant
               (-3 -5 9=0 "[0] entf./o.A. (incl. Besuch allg.bild. Schule)") ///
               (-9 = 0)   /// mz 2015 -9 Entfällt (Fehler in der Filterführung)
               (6=1       "[1] kein AB") ///  
               (1=2       "[2] HS/VS")  ///
               (2 3 7=3   "[3] RS/POS") ///
               (4 5=4     "[4] FHR/ABI"), generate(schul)
replace schul=1 if (ef309_3==8)
/* Berufsbildender Abschluss (ber)
 Neue Kategorien in EF312:
16 Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig 
   (z.B. Physiotherapie, Gesundeits- und Krankenpflege, MTA, Altenpflege)
17 Ausbildungsstätten/Schulen für Erzieher	
* Kategorie 7 umfasst nur noch 2-jährige Bildungsgänge
 7 Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 2-jährig 
  (z.B. Masseur, Medizinischer Bademeister, PTA, Podologe) */
recode ef312_3 (-7 -8=.)   /// Entfällt, für Querschnittsausw. nicht relevant
               (-3 -5 99=0   "[0] entf./o.A.") ///
               (1/10 16 17=2 "[2] Ausb.") ///
               (11/13=3      "[3] FH/Berufsakad.") /// incl. Verw.-FH, Duale HS
               (14/15=4      "[4] Uni") ///
                /// (16=2)       /// mz15: 16: Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig (z.B. Physiotherapie, Gesundeits- und Krankenpflege, MTA,Altenpflege)
                /// (17=2)
       , generate(ber) // mz15 17: Ausbildungsstätten/Schulen für Erzieher
replace ber=1 if (ef311_3==8)
* drop cas casa
generate cas=99 if schul!=. & ber!=.
replace cas=99 if (schul==0 | ber==0)
replace cas=0  if (((schul==0 | schul==1) & ber==1)  | (schul==1 & ber==0))
replace cas=1  if (schul==2 & (ber==0 | ber==1))
replace cas=2  if ((schul==0 | schul==1 | schul==2) & ber==2)
replace cas=3  if (schul==3 & (ber==0 | ber==1))
replace cas=4  if (schul==3 & ber==2)
replace cas=5  if (schul==4 & (ber==0 | ber==1))
replace cas=6  if (schul==4 & ber==2)
replace cas=7  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==3)
replace cas=8  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==4)
generate casa=cas if schul!=. & ber!=.
replace casa=9 if (ef287_3>=1 & ef287_3<=2)
replace casa = 90 if casa== 9 // [9] in Ausbildung | if (ef287_3>=1 & ef287_3<=2)
replace casa =  9 if casa==90 & ef290_3==1  // [1] Klassenstufe 1 bis 4
replace casa = 10 if casa==90 & ef290_3==2  // [2] Klassenstufe 5 bis 9/10
replace casa = 11 if casa==90 & ef290_3==3  // [3] Gymnasiale Oberstufe
replace casa = 12 if casa==90 & ef289_3==12 // [12] Berufliche Schule, die zur mittleren Reife führt (z.B. Berufsfachschule)
replace casa = 13 if casa==90 & ef289_3>=13 & ef289_3<=15 // [13] Berufliche Schule, die zur Hochschul-/Fachhochschulreife führt: Fachoberschule, Berufsfachschule, Berufsoberschule, technische Oberschule
replace casa = 14 if casa==90 & ef289_3>=16 & ef289_3<=19 // [16] Berufsvorbereitungsjahr, [17] Berufsgrundbildungsjahr, [18] Berufsschule, [19] Berufsfachschule, die einen Berufsabschluss vermittelt
replace casa = 15 if casa==90 & ef289_3>=20 & ef289_3<=24 // [20] Schulen für Gesundheits-­ und Sozialberufe: einjährig [21] zwei-/dreijährig [22] Fachschule [23] Fachakademie (BY) [24] Berufsakademie
replace casa = 16 if casa==90 & ef289_3>=25 & ef289_3<=28 // [25] Verwaltungsfachhochschule [26] Fachhochschule [27] Universität [28] Promotionsstudium
replace casa =  0 if casa==99 // dominant: ef309_3: [-3] Entfällt (Person unter 15 Jahren), [9] Keine Angabe
replace casa =  0 if casa==90 & ef310_3>=-5 & ef310_3<=-3
replace casa =  1 if casa==90 & ef310_3==1 & (ef312_3==-5 | ef312_3==1)
replace casa =  2 if casa==90 & ef310_3==1 & (ef312_3==3  | ef312_3==4)
replace casa =  3 if casa==90 & ef310_3==3 &  ef312_3==-5
replace casa =  4 if casa==90 & ef310_3==3 & (ef312_3==3  | ef312_3==4)
replace casa =  5 if casa==90 & ef310_3>=4 & ef310_3<=5 & ef312_3==-5
replace casa =  6 if casa==90 & ef310_3>=4 & ef310_3<=5 & ef312_3>=3 & ef312_3<=4
replace casa =  6 if casa==90 & ef310_3>=4 & ef310_3<=5 & ef312_3==11
replace casa =  8 if casa==90 & ef310_3>=4 & ef310_3<=5 & ef312_3==14
replace casa =  0 if casa==90 & ef310_3==9 & ef312_3==-5
replace casa = 16 if casa==90 & ef289_3>=29 & ef289_3<=30 // [29] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig | [30] Ausbildungsstätten/Schulen für Erzieher
replace casa =  0 if casa==90 & ef310_3==6 & ef312_3==-5 // ef310 [6] Abschluss nach höchstens 7 Jahren 
replace casa =  3 if casa==90 & ef310_3==3 & ef312_3==1  // ef310 [3] RS ef312 [1] Anlernausbildung
replace casa =  4 if casa==90 & ef310_3==7 & ef312_3==3  // ef310 [3] RS ef312 [3] Lehre
replace casa =  4 if casa==90 & ef310_3==3 & ef312_3==6  // ef312 [6] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 1-jährig
replace casa =  6 if casa==90 & ef310_3==5 & ef312_3==7 //  ef310 [5] ABI ef312 [7] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 2-jährig
replace casa =  4 if casa==90 & ef310_3==3 & ef312_3==8  // ef312 [6] Meister, Techniker
replace casa =  7 if casa==90 & ef310_3==5 & ef312_3==12 // ef312 [12] Verwaltungs-FH
replace casa =  7 if casa==90 & ef310_3>=4 & ef310_3<=5 & ef312_3==13 // ef312 [13] FH
replace casa =  6 if casa==90 & ef310_3==4 & ef312_3==17 // ef312 [17] Ausbildungsstätten/Schulen für Erzieher
replace casa =  4 if casa==90 & ef310_3==3 & ef312_3==16 // ef312 [16] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig 
replace casa =  3 if casa==90 & ef310_3==3 & ef312_3==99 // ef312 [99] kA
replace casa =  5 if casa==90 & ef310_3==5 & ef312_3==99 // ef312 [99] kA
replace casa =  0 if casa==90 & ef310_3==9 & ef312_3==99 // ef312 [99] kA
recode casa (0=0)       /// Kein Abschluss, keine Angabe
            (1 3 = 1)   /// HS, RS ohne Berufsausb.
            (2 4 = 2)   /// RS, RS mit Berufsausb.
            (5/8 = 3)   /// Abi, FH, UNI
            (9 10 = 4)  /// Schulbes. Klasse 1-9/10
            (11/16 = 5) /// Schul-/Hochschulbes. GYO-Prom
 , gen(casr_3) // ex (casar_3)
drop casa 
replace casr_3 = 0 if casr_3==90 & ef310_3==-9 & ef312_3==-5
recode casr_3 (-9=9)
lab var casr_3 "Casmin & Schulbes. recodiert - t3" // casar_3
lab val casr_3 casr // casar_3 casar

drop schul ber cas 
recode ef310_4 (-7 -8=.) /// Entfällt, für Querschnittsausw. nicht relevant  ex EF310
               (-3 -5 9=0 "[0] entf./o.A. (incl. Besuch allg.bild. Schule)") ///
               (-9=0)                    /// -9 Entfällt (Fehler in der Filterführung)
               (6=1       "[1] kein AB") ///  
               (1=2       "[2] HS/VS")   ///
               (2 3 7=3   "[3] RS/POS")  ///
               (4 5=4     "[4] FHR/ABI"), generate(schul)
replace schul=1 if (ef309_4==8) // ex EF
recode ef312_4 (-7 -8=.)   /// Entfällt, für Querschnittsausw. nicht relevant // ex EF
               (-3 -5 99=0   "[0] entf./o.A.") ///
               (1/10 16 17=2 "[2] Ausb.") ///
               (11/13=3      "[3] FH/Berufsakad.") /// incl. Verw.-FH, Duale HS
               (14/15=4      "[4] Uni"), generate(ber)
replace ber=1 if (ef311_4==8)
generate cas=99 if schul!=. & ber!=.
replace cas=99 if (schul==0 | ber==0)
replace cas=0  if (((schul==0 | schul==1) & ber==1)  | (schul==1 & ber==0))
replace cas=1  if (schul==2 & (ber==0 | ber==1))
replace cas=2  if ((schul==0 | schul==1 | schul==2) & ber==2)
replace cas=3  if (schul==3 & (ber==0 | ber==1))
replace cas=4  if (schul==3 & ber==2)
replace cas=5  if (schul==4 & (ber==0 | ber==1))
replace cas=6  if (schul==4 & ber==2)
replace cas=7  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==3)
replace cas=8  if ((schul==0 | schul==1 | schul==2 | schul==3 | schul==4) & ber==4)
generate casa=cas if schul!=. & ber!=.
drop cas
replace casa=9 if (ef287_4>=1 & ef287_4<=2) // ex EF
drop schul ber
* ENDE harmonisierte CASMIN-Klassifikation
replace casa = 90 if casa== 9 // [9] in Ausbildung | if (ef287_4>=1 & ef287_4<=2)
replace casa =  9 if casa==90 & ef290_4==1  // [1] Klassenstufe 1 bis 4
replace casa = 10 if casa==90 & ef290_4==2  // [2] Klassenstufe 5 bis 9/10
replace casa = 11 if casa==90 & ef290_4==3  // [3] Gymnasiale Oberstufe
replace casa = 12 if casa==90 & ef289_4==12 // [12] Berufliche Schule, die zur mittleren Reife führt (z.B. Berufsfachschule)
replace casa = 13 if casa==90 & ef289_4>=13 & ef289_4<=15 // [13] Berufliche Schule, die zur Hochschul-/Fachhochschulreife führt: Fachoberschule, Berufsfachschule, Berufsoberschule, technische Oberschule
replace casa = 14 if casa==90 & ef289_4>=16 & ef289_4<=19 // [16] Berufsvorbereitungsjahr, [17] Berufsgrundbildungsjahr, [18] Berufsschule, [19] Berufsfachschule, die einen Berufsabschluss vermittelt
replace casa = 15 if casa==90 & ef289_4>=20 & ef289_4<=24 // [20] Schulen für Gesundheits-­ und Sozialberufe: einjährig [21] zwei-/dreijährig [22] Fachschule [23] Fachakademie (BY) [24] Berufsakademie
replace casa = 16 if casa==90 & ef289_4>=25 & ef289_4<=28 // [25] Verwaltungsfachhochschule [26] Fachhochschule [27] Universität [28] Promotionsstudium
replace casa = 16 if casa==90 & ef289_4>=29 & ef289_4<=30 // [29] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 3-jährig | [30] Ausbildungsstätten/Schulen für Erzieher
replace casa =  0 if casa==99 // dominant: ef309: [-3] Entfällt (Person unter 15 Jahren), [9] Keine Angabe
replace casa =  0 if casa==90 & ef310_4>=-5 & ef310_4<=-3
replace casa =  1 if casa==90 & ef310_4==1 & (ef312_4==-5 | ef312_4==1)
replace casa =  2 if casa==90 & ef310_4==1 & (ef312_4==3  | ef312_4==4)
replace casa =  3 if casa==90 & ef310_4==3 &  ef312_4==-5
replace casa =  4 if casa==90 & ef310_4==3 & (ef312_4==3  | ef312_4==4)
replace casa =  5 if casa==90 & ef310_4>=4 & ef310_4<=5 & ef312_4==-5
replace casa =  6 if casa==90 & ef310_4>=4 & ef310_4<=5 & ef312_4>=3 & ef312_4<=4
replace casa =  6 if casa==90 & ef310_4>=4 & ef310_4<=5 & ef312_4==11
replace casa =  8 if casa==90 & ef310_4>=4 & ef310_4<=5 & ef312_4==14
replace casa =  0 if casa==90 & ef310_4==9 & ef312_4==-5
replace casa = 0 if casa==90 & ef310_4==-9 & ef312_4==-5 // ef310_4 [-9] Filterfehler
replace casa = 0 if casa==90 & ef310_4==-9 & ef312_4==3  // ef312 [3] Lehre
replace casa = 4 if casa==90 & ef310_4==3  & ef312_4==7  // ef312 [7] Ausbildungsstätten/Schulen für Gesundheits-/Sozialberufe: 2-jährig
replace casa = 7 if casa==90 & ef310_4==4  & ef312_4==13 // ef312 [13] FH
replace casa = 0 if casa==90 & ef310_4==-9 & ef312_4==99 // ef312 [99] kA
recode casa (0=0)       /// Kein Abschluss, keine Angabe
            (1 3 = 1)   /// HS, RS ohne Berufsausb.
            (2 4 = 2)   /// RS, RS mit Berufsausb.
            (5/8 = 3)   /// Abi, FH, UNI
            (9 10 = 4)  /// Schulbes. Klasse 1-9/10
            (11/16 = 5) /// Schul-/Hochschulbes. GYO-Prom
  , gen(casar)
drop casa  
gen casr_4= casar
drop casar
recode casr_4 (-9=9)
lab val casr_4 casr // casar
lab var casr_4 "Casmin & Schulbes. recodiert - t4"

lab def casr 0 "Kein Abschluss, keine Angabe" /// casar
           1 "HS, RS ohne Berufsausb." ///
           2 "HS, RS mit Berufsausb." ///
           3 "Abi, FH, UNI" ///
           4 "Schulbes. Klasse 1-9/10" ///
           5 "Schul-/Hochschulbes. GYO-Prom", add modify		   
numlabel casr, add mask("[#] ") force // casar
for var casr_1 casr_2 casr_3 casr_4 : lab val X casr 

for var casr_1 casr_2 casr_3 \ var r1 r2 r3 : tab X if Y==1, m

* ------------------------------------------------------------------------------

* eink_* -- Pers. Nettoeink. ~ Quartile ~
recode ef436_1 ef436_2 ef436_3 ef436_4 /// Recodierung ~ Quartile ~ nach  tab ef436_1  if eink_1>=1 & eink_1<=99999 & t1==1 & ef5b_1==0 & ef436_1>0 & ef30_1>=1 & ef30_1<=2
               (1/4   = 1)    /// bis unter  700 Euro      ~  25 % Cum.
               (5/7   = 2)    /// 700 bis unter 1300 Euro  ~  50 %
               (8/10  = 3)    /// 1300 bis unter 2000 Euro ~  75 %
               (11/24 = 4)    /// 2000 unt mehr Euro       ~ 100   %
               (50 90 99 = 5) /// Selbst.Landw. (50), Kein Eink. (90), Keine Angabe (99)
               (-8 -7 . = .)  ///
        , gen(eink_1 eink_2 eink_3 eink_4)
lab var eink_1 "Pers. Nettoeink. ~ Quartile ~ - t1"
lab var eink_2 "Pers. Nettoeink. ~ Quartile ~ - t2"
lab var eink_3 "Pers. Nettoeink. ~ Quartile ~ - t3"
lab var eink_4 "Pers. Nettoeink. ~ Quartile ~ - t4"
lab def eink 1 "1 - 699" 2 "700-1299"  3 "1300-1999" 4 "2000<=" ///
             5 "Ohne Eink.angabe"
numlabel eink, add mask("[#] ") force
for var eink_1 eink_2 eink_3 eink_4 : lab val X eink

for var eink_1 eink_2 eink_3 \ var r1 r2 r3 : tab  X if Y==1, m

* ------------------------------------------------------------------------------

save panel_v4a.dta, replace
* n=120.945 

log close
