* prog_4b.do

/* Programme zu:
Schimpl-Neimanns, Bernhard (2021): Ausfallkorrektur und Designgewichtung im 
Mikrozensuspanel 2012 – 2015. GESIS Papers 2021|14. Köln: GESIS.
https://doi.org/10.21241/ssoar.75410
https://www.gesis.org/missy/files/documents/MZ/Programme_GESIS-Report_2021_14.zip

Programmautor: Bernhard Schimpl-Neimanns

* Modelle zur Ausfallkorrektur/-gewichtung
*/

* Stata 16.1
set dp comma
set linesize 255
set varabbrev off
set seed 54721

cd "<Verzeichnis>" // eintragen, z. B. C:\Daten\mzpanel

log using test_prog_4b.log, text 

use panel_v4a.dta, replace

* Designgewichte 2-, 3-, 4-Wellen, Übergänge 2012/13, 2013/14, 2014/15 für
* - wohnberechtigte Bevölkerung
* - Bevölkerung am Hauptwohnsitz
* siehe Abschnitt 2.2 Längsschnittpopulation und Längsschnittgewichte

* === AUSWAHL: rot=82 & att>=0 & att<=1
* Zielpopulation: Wohnberechtigte Bevölkerung in Privathaushalten und 
*                Gemeinschaftsunterkünften
* Rotationsgruppe 82 (2012-2015 in Stichprobe), Response & Attrition
* - ohne temporäre Ausfälle (Wiedereintritte)
* - ohne Späteintritte
* - ohne Ausfallsätze
keep if rot==82 & att>=0 & att<=1

* ------------------------------------------------------------------------------

* Synthetische HH-Nummern (incl. Gem.unterk.) für Übergänge (inkl. Sterbefälle)
destring idhh, gen(idhh_num) 
format idhh_num %11.0f

* Übergang 2012->13: r1==1 & r2>=0 & r2<=1
gen double idhhs_2 = idhh_num * 10 + r2 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1
format idhhs_2 %12.0f
lab var  idhhs_2 "ID synth. Haushalt (incl. Gem.Unterk.) Zielpop Übergang 2012->2013"

* Übergang 2013->14
gen double idhhs_3 = idhh_num * 10 + r3 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3>=0 & r3<=1
format idhhs_3 %12.0f
lab var  idhhs_3 "ID synth. Haushalt (incl. Gem.Unterk.) Zielpop Übergang 2013->2014"

* Übergang 2014->2015 ohne Sterbefälle !
gen double idhhs_4 = idhh_num * 10 + r4 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4>=0 & r4<=1
format idhhs_4 %12.0f
lab var  idhhs_4 "ID synth. Haushalt (incl. Gem.Unterk.) Zielpop Übergang 2014->2015"

* ------------------------------------------------------------------------------

* Designgewicht mit Inklusionswahrscheinlichkeiten für eine Rotationsgruppe
* d̃ _k = 1⁄π_k * 1/1000
gen double d = 1/(.01 * .70 * .25) * 1/1000
lab var d "Designgewicht 1/π_k für 1 Rotationsgruppe (in 1.000)"
format d %10.8f

/* Logitmodell, Berücksichtigung der Korrelation in synth. HH vce(cluster idhhs) 
Ausschluss der Sterbefälle (verltypr_*!=1)
-----------------------------------------------------
Variable   Referenzkategorie
west_ost    1  West
altr_      50  50-54 Jahre
famst_      2  verheiratet zus.leb., eLP zus.leb.
hws_        1  Hauptwohnsitz
hhtyp_      0  Privathaushalt
nat_        1  deutsch
sex_        1  männlich
casr_       2  Haupt-/Realschule mit Berufsausbildung
eink_       2  700-1299 Euro
*/

* ==============================================================================

* Übergang 2012->13 ohne Sterbefälle

* Nullmodell
logit r2 if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & r1==1 & r2>=0 & r2<=1, vce(cluster idhhs_2)
estimates store m0

logit r2 ib1.west_ost ///
         ib50.altr_1 ib2.famst_1 ib1.hws_1 ib0.hhtyp_1 ib1.nat_1 ib1.sex_1 ib2.casr_1 ib2.eink_1 ///
  if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1 & verltypr_2!=1, /// 
     vce(cluster idhhs_2)
estimates store m1
* estout m1, cells("b se z p") stats(N r2_p ll_0 ll chi2 df_m p bic)
estat ic
 	
* Pseudo-Likelihood-Ratio
lrtest m1 m0, force

* ------------------------------------------------------------------------------

/* Im MZ-Panel 2012-2015 können Ausfallsätze nicht eindeutig einer 
Rotationsgruppe zugeordnet werden. Es wird deshalb davon ausgegangen, dass es 
2012 keine Ausfälle gibt, sondern durch die Zuordnung der Jahresüberhänge aus 
der Erhebung 2013 zum Panelzeitpunkt 2012 alle Ausfälle in t_1 erfasst sind.  
w_1 wird deshalb auf 1 gesetzt. 
*/
* θ̂_1 = 1, w_1 = 1
gen byte w_1 = 1 if rot==82 & att>=0 & att<=1 & r1==1
lab var w_1 "Gewicht Startpop. 2012"

* θ̂_2.1 = p̂ (r_2=1|z,x_1,r_1=1) Wahrscheinlichkeit räumlicher Immobilität 
predict double p_immo_2 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & verltypr_2!=1, pr
lab var p_immo_2 "Wahrscheinlichkeit räumlicher Immobilität 2012-13"

* w_2.1  = 1 ⁄ (p̂ (r_2=1|z,x_1,r_1=1)) 
gen double w_2_1  = 1/p_immo_2
lab var w_2_1 "Korrekturgewicht Kompensation 12->13 fortgez. Pers. (in 1.000)"

* w_2 = w_1 * w_2.1
gen double w_2    = w_1 * w_2_1
lab var w_2 "Endgewicht Panel 12-13 (in 1.000)"

* d̃_2 = d_k * w_2
gen double d_2 = d * w_2
lab var d_2 "Korrigiertes Designgewicht Panel 12-13 (in 1.000) - wohnber. Bev."

* tabstat r1 d p_immo_2 w_2_1 w_2 d_2 if rot==82 & att>=0 & att<=1 & r1==1  & verltypr_2!=1, s(count sum mean)

* tabstat r1 r2 d p_immo_2 w_2_1 w_2 d_2 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & verltypr_2!=1, s(count sum mean)

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 2-Wellen-Panel 2012-2013, wohnberechtigte Bevölkerung
quietly : tab r1 if r1==1 & att>=0 & att<=1 & verltypr_2!=1 [iw=d]
scalar u = r(N)
qui: tab r2 if r1==1 & r2==1 & att>=0 & att<=1 & verltypr_2!=-1 [iw=d_2]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_2_norm = d_2 * (u/v) if r1==1 & r2==1 & att>=0 & att<=1 & verltypr_2!=1
lab var d_2_norm "Korrigiertes Designgewicht Panel 12-13 normiert (in 1.000) - wohnber. Bev."

* tab nat_2 nat_1 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & verltypr_2!=1 [iw=d_2_norm],  row col

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 2-Wellen-Panel 2012-2013, Bevölkerung am Hauptwohnsitz 2012
quietly : tab hws_1 if r1==1 & r2>=0 & r2<=1 & att>=0 & att<=1 & verltypr_2!=1 & hws_1==0 [iw=d]
scalar u = r(N)
qui: tab hws_1 if r1==1 & r2==1 & att>=0 & att<=1 & verltypr_2!=1 & hws_1==0 [iw=d_2]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_2_norm_hws = d_2 * (u/v) if hws_1==0 & r2==1 & verltypr_2!=1
lab var d_2_norm_hws "Korrigiertes Designgewicht Panel 12-13 normiert Bev. am Hauptw. t1 (in 1.000)"

* tab hws_2 if hws_1==0 [iw=d_2_norm_hws]

* =============================================================================

* Übergang 2013->14 ohne Sterbefälle

* Nullmodell 
logit r3 if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & r1==1 & r2==1 & r3>=0 & r3<=1, vce(cluster idhhs_3)
estimates store m0

logit r3 ib1.west_ost ///
         ib50.altr_1 ib2.famst_1 ib1.hws_1 ib0.hhtyp_1 ib1.nat_1 ib1.sex_1 ib2.casr_1 ib2.eink_1 ///
         ib50.altr_2 ib2.famst_2 ib1.hws_2 ib0.hhtyp_2 ib1.nat_2 ib1.sex_2 ib2.casr_2 ib2.eink_2 ///
  if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & r1==1 & r2==1 & r3>=0 & r3<=1 , ///
     vce(cluster idhhs_3)
estimates store m2
* estout m2, cells("b se z p") stats(N r2_p ll_0 ll chi2 df_m p bic)
estat ic
* Pseudo-Likelihood-Ratio
lrtest m0 m2, force

* θ̂_3.12 = p̂(r_3=1|z,x_1,x_2,r_1=r_2=1) Wahrscheinlichkeit räumlicher Immobilität
predict double p_immo_3 if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & r1==1 & r2==1 & r3==1, pr
lab var p_immo_3 "Wahrscheinlichkeit räumlicher Immobilität 2012-14"

* w_3.12 = 1⁄((p^ (r_3=1|z,x_1,x_2,r_1=r_2=1))
gen double w_3_12  = 1/p_immo_3
lab var w_3_12 "Korrekturgewicht Kompensation 13->14 fortgez. Pers. (in 1.000)"

* w_3 = w_1 * w_2.1 * w_3.12
gen double w_3    = w_1 * w_2_1 * w_3_12
lab var w_3 "Endgewicht Panel 12-14 (in 1.000)"

* d̃_3 = d_k * w_3
gen double d_3 = d * w_3
lab var d_3 "Korrigiertes Designgewicht Panel 12-14 (in 1.000) - wohnber. Bev."

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 3-Wellen-Panel 2012-2014, wohnberechtigte Bevölkerung
qui : tab r1 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1 & r3>=0 & r3<=1 & verltypr_2!=1 & verltypr_3!=1 [iw=d]
scalar u = r(N)
qui : tab r3 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1 [iw=d_3]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_3_norm = d_3 * (u/v) if r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1
lab var d_3_norm "Korrigiertes Designgewicht Panel 12-14 normiert (in 1.000) - wohnber. Bev."

* tab nat_3 nat_1 [iw=d_3_norm] 

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 3-Wellen-Panel 2012-2014, Bevölkerung am Hauptwohnsitz 2012
quietly : tab hws_1 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1 & r3>=0 & r3<=1 & verltypr_2!=1 & verltypr_3!=1 & hws_1==0 [iw=d], m 
scalar u = r(N)
qui: tab hws_3 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1 & hws_1==0 [iw=d_3]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_3_norm_hws = d_3 * (u/v) if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1 & hws_1==0
lab var d_3_norm_hws "Korrigiertes Designgewicht Panel 12-14 normiert Bev. am Hauptw. t1 (in 1.000)"

* tab hws_3 if hws_1==0 [iw=d_3_norm_hws]

* ==============================================================================

* Übergang 14->15 ohne Sterbefälle
* Nullmodell 
logit r4 if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & r1==1 & r2==1 & r3==1 & r4>=0 & r4<=1, vce(cluster idhhs_4)
estimates store m0

logit r4 ib1.west_ost ///
         ib50.altr_1 ib2.famst_1 ib1.hws_1 ib0.hhtyp_1 ib1.nat_1 ib1.sex_1 ib2.casr_1 ib2.eink_1 ///
         ib50.altr_2 ib2.famst_2 ib1.hws_2 ib0.hhtyp_2 ib1.nat_2 ib1.sex_2 ib2.casr_2 ib2.eink_2 ///
         ib50.altr_3 ib2.famst_3 ib1.hws_3 ib0.hhtyp_3 ib1.nat_3 ib1.sex_3 ib2.casr_3 ib2.eink_3 ///
  if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & r1==1 & r2==1 & r3==1 & r4>=0 & r4<=1, ///
     vce(cluster idhhs_4)
estimates store m3
* estat ic
estout m3, cells("b se z p") stats(N r2_p ll_0 ll chi2 df_m p bic)

* Pseudo-Likelihood-Ratio
lrtest m0 m3, force

* θ̂_4.123 = (p̂ (r_4=1|z,x_1,x_2,x_3,r_1=r_2=r_3=1)) Wahrscheinlichkeit räumlicher Immobilität
predict double p_immo_4 if rot==82 & att>=0 & att<=1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & r1==1 & r2==1 & r3==1 & r4==1, pr 
lab var p_immo_4 "Wahrscheinlichkeit räumlicher Immobilität 2012-15"

* θ̂_4.123 = 1⁄(p̂ (r_4=1|z,x_1,x_2,x_3,r_1=r_2=r_3=1))
gen double w_4_123  = 1/p_immo_4
lab var w_4_123 "Korrekturgewicht Kompensation 14->15 fortgez. Pers. (in 1.000)"

* θ̂_4 = θ̂_1 * θ̂_2.1 * θ̂_3.12 * θ̂_4.123
gen double w_4    = w_1 * w_2_1 * w_3_12  * w_4_123
lab var w_4 "Endgewicht für Panel 12-15 (in 1.000)"

* d̃ _4 = d̃ _k * θ̂_4
gen double d_4 = d * w_4
lab var d_4 "Korrigiertes Designgewicht Panel 12-15 (in 1.000) - wohnber. Bev."

* tabstat r1 r4 d p_immo_4 w_4_123 w_4 d_4 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1, s(count sum mean)

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 4-Wellen-Panel 2012-2015, wohnberechtigte Bevölkerung
qui : tab r1 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1 & r3>=0 & r3<=1 & r4>=0 & r4<=1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 [iw=d]
scalar u = r(N)
qui : tab r4 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 [iw=d_4]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_4_norm = d_4 * (u/v) if r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1
lab var d_4_norm "Korrigiertes Designgewicht Panel 12-15 normiert (in 1.000) wohnber. Bevölkerung"

* tab nat_4 nat_1 [iw=d_4_norm]

* ------------------------------------------------------------------------------

* Normiertes korrigiertes Designgewicht 4-Wellen-Panel 2012-2015, Bevölkerung am Hauptwohnsitz 2012
quietly : tab hws_4 if rot==82 & att>=0 & att<=1 & r1==1 & r2>=0 & r2<=1 & r3>=0 & r3<=1 & r4>=0 & r4<=1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & hws_1==0 [iw=d], m 
scalar u = r(N)
qui: tab hws_4 if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & hws_1==0 [iw=d_4]
scalar v = r(N)
scalar list
di "n_t1 = " u " | n^ gewichtet = " v " | Korrekturfaktor = " u/v

gen double d_4_norm_hws = d_4 * (u/v) if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & hws_1==0
lab var d_4_norm_hws "Korrigiertes Designgewicht Panel 12-15 normiert Bev. am Hauptw. t1 (in 1.000)"

* tab hws_4 if hws_1==0 [iw=d_4_norm_hws]

* ==============================================================================

* Tabelle 8: Mittelwerte korrigierter Längsschnittgewichte, normiert für die 
* Bevölkerung am Hauptwohnsitz 2012 
* HIER NUR MIT Ausschluss imputierter Sterbefälle nach Altersgruppe (2012) 

* 2-Wellen, 2012 - 2013
tabstat d_2_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & verltypr_2!=1 & hws_1==0, s(mean) by(altr_1) format(%6.4f)
/*
    altr_1 |      mean
-----------+----------
   [0] 0-4 |    0,6729
   [5] 5-9 |    0,6311
[10] 10-14 |    0,6180
[15] 15-19 |    0,6419
[20] 20-24 |    0,7645
[25] 25-29 |    0,7588
[30] 30-34 |    0,6967
[35] 35-39 |    0,6519
[40] 40-44 |    0,6245
[45] 45-49 |    0,6136
[50] 50-54 |    0,6083
[55] 55-59 |    0,6013
[60] 60-64 |    0,5990
[65] 65-69 |    0,5958
[70] 70-74 |    0,5917
[75] 75-79 |    0,5980
[80] 80-84 |    0,6223
[85] 85-89 |    0,6419
[90] 90-99 |    0,6996
-----------+----------
     Total |    0,6352
----------------------
*/

tabstat d_2_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & verltypr_2!=1 & hws_1==0, s(sum) format(%6.0f)
/*
    variable |       sum
-------------+----------
d_2_norm_hws |     67742
------------------------
*/

* ------------------------------------------------------------------------------

* 3-Wellen, 2012 - 2014
tabstat d_3_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1 & hws_1==0, s(mean) by(altr_1) format(%6.4f)
/*
    altr_1 |      mean
-----------+----------
   [0] 0-4 |    0,7668
   [5] 5-9 |    0,6878
[10] 10-14 |    0,6627
[15] 15-19 |    0,7277
[20] 20-24 |    1,0050
[25] 25-29 |    0,9924
[30] 30-34 |    0,8224
[35] 35-39 |    0,7264
[40] 40-44 |    0,6751
[45] 45-49 |    0,6533
[50] 50-54 |    0,6399
[55] 55-59 |    0,6279
[60] 60-64 |    0,6258
[65] 65-69 |    0,6200
[70] 70-74 |    0,6159
[75] 75-79 |    0,6269
[80] 80-84 |    0,6708
[85] 85-89 |    0,7299
[90] 90-99 |    0,8575
-----------+----------
     Total |    0,6960
----------------------
*/

tabstat d_3_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & verltypr_2!=1 & verltypr_3!=1 & hws_1==0, s(sum) format(%6.0f)
/*
    variable |       sum
-------------+----------
d_3_norm_hws |     67466
------------------------
*/

* ------------------------------------------------------------------------------

* 4-Wellen, 2012 - 2015
tabstat d_4_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & hws_1==0, s(mean) by(altr_1) format(%6.4f)
/*
    altr_1 |      mean
-----------+----------
   [0] 0-4 |    0,8839
   [5] 5-9 |    0,7575
[10] 10-14 |    0,7149
[15] 15-19 |    0,8572
[20] 20-24 |    1,3633
[25] 25-29 |    1,2893
[30] 30-34 |    0,9770
[35] 35-39 |    0,8188
[40] 40-44 |    0,7341
[45] 45-49 |    0,6998
[50] 50-54 |    0,6849
[55] 55-59 |    0,6675
[60] 60-64 |    0,6619
[65] 65-69 |    0,6524
[70] 70-74 |    0,6467
[75] 75-79 |    0,6704
[80] 80-84 |    0,7445
[85] 85-89 |    0,8638
[90] 90-99 |    1,1553
-----------+----------
     Total |    0,7702
*/

tabstat d_4_norm_hws   if rot==82 & att>=0 & att<=1 & r1==1 & r2==1 & r3==1 & r4==1 & verltypr_2!=1 & verltypr_3!=1 & verltypr_4!=1 & hws_1==0, s(sum) format(%6.0f)
/*
    variable |       sum
-------------+----------
d_4_norm_hws |     67201
------------------------
*/

* ==============================================================================

compress

save panel_4b.dta, replace

log close
